/* object-cache.c generated by valac 0.26.2.1-1f25, the Vala compiler
 * generated from object-cache.vala, do not modify */


#include <glib.h>
#include <glib-object.h>
#include <stdlib.h>
#include <string.h>
#include <folks/folks.h>
#include <folks-test.h>
#include <gio/gio.h>
#include <gee.h>
#include <float.h>
#include <math.h>
#include <gobject/gvaluecollector.h>


#define TYPE_TEST_OBJECT (test_object_get_type ())
#define TEST_OBJECT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_TEST_OBJECT, TestObject))
#define TEST_OBJECT_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_TEST_OBJECT, TestObjectClass))
#define IS_TEST_OBJECT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_TEST_OBJECT))
#define IS_TEST_OBJECT_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_TEST_OBJECT))
#define TEST_OBJECT_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_TEST_OBJECT, TestObjectClass))

typedef struct _TestObject TestObject;
typedef struct _TestObjectClass TestObjectClass;
typedef struct _TestObjectPrivate TestObjectPrivate;
#define _g_free0(var) (var = (g_free (var), NULL))
typedef struct _ParamSpecTestObject ParamSpecTestObject;

#define TYPE_TEST_CACHE (test_cache_get_type ())
#define TEST_CACHE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_TEST_CACHE, TestCache))
#define TEST_CACHE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_TEST_CACHE, TestCacheClass))
#define IS_TEST_CACHE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_TEST_CACHE))
#define IS_TEST_CACHE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_TEST_CACHE))
#define TEST_CACHE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_TEST_CACHE, TestCacheClass))

typedef struct _TestCache TestCache;
typedef struct _TestCacheClass TestCacheClass;
typedef struct _TestCachePrivate TestCachePrivate;
#define _g_variant_unref0(var) ((var == NULL) ? NULL : (var = (g_variant_unref (var), NULL)))

#define TYPE_OBJECT_CACHE_TESTS (object_cache_tests_get_type ())
#define OBJECT_CACHE_TESTS(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_OBJECT_CACHE_TESTS, ObjectCacheTests))
#define OBJECT_CACHE_TESTS_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_OBJECT_CACHE_TESTS, ObjectCacheTestsClass))
#define IS_OBJECT_CACHE_TESTS(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_OBJECT_CACHE_TESTS))
#define IS_OBJECT_CACHE_TESTS_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_OBJECT_CACHE_TESTS))
#define OBJECT_CACHE_TESTS_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_OBJECT_CACHE_TESTS, ObjectCacheTestsClass))

typedef struct _ObjectCacheTests ObjectCacheTests;
typedef struct _ObjectCacheTestsClass ObjectCacheTestsClass;
typedef struct _ObjectCacheTestsPrivate ObjectCacheTestsPrivate;
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))
#define _g_error_free0(var) ((var == NULL) ? NULL : (var = (g_error_free (var), NULL)))
typedef struct _Block1Data Block1Data;
#define _g_main_loop_unref0(var) ((var == NULL) ? NULL : (var = (g_main_loop_unref (var), NULL)))
#define _test_object_unref0(var) ((var == NULL) ? NULL : (var = (test_object_unref (var), NULL)))
typedef struct _Block2Data Block2Data;
typedef struct _Block3Data Block3Data;
typedef struct _Block4Data Block4Data;
typedef struct _Block5Data Block5Data;
typedef struct _Block6Data Block6Data;
typedef struct _Block7Data Block7Data;
typedef struct _Block8Data Block8Data;
typedef struct _Block9Data Block9Data;
typedef struct _Block10Data Block10Data;
typedef struct _Block11Data Block11Data;
#define _vala_assert(expr, msg) if G_LIKELY (expr) ; else g_assertion_message_expr (G_LOG_DOMAIN, __FILE__, __LINE__, G_STRFUNC, msg);

struct _TestObject {
	GTypeInstance parent_instance;
	volatile int ref_count;
	TestObjectPrivate * priv;
};

struct _TestObjectClass {
	GTypeClass parent_class;
	void (*finalize) (TestObject *self);
};

struct _TestObjectPrivate {
	gchar* _my_string;
	guint _my_int;
};

struct _ParamSpecTestObject {
	GParamSpec parent_instance;
};

struct _TestCache {
	FolksObjectCache parent_instance;
	TestCachePrivate * priv;
};

struct _TestCacheClass {
	FolksObjectCacheClass parent_class;
};

struct _ObjectCacheTests {
	FolksTestCase parent_instance;
	ObjectCacheTestsPrivate * priv;
};

struct _ObjectCacheTestsClass {
	FolksTestCaseClass parent_class;
};

struct _ObjectCacheTestsPrivate {
	GFile* _cache_dir;
};

struct _Block1Data {
	int _ref_count_;
	ObjectCacheTests* self;
	GMainLoop* main_loop;
	TestCache* cache;
};

struct _Block2Data {
	int _ref_count_;
	ObjectCacheTests* self;
	GMainLoop* main_loop;
	TestCache* cache;
};

struct _Block3Data {
	int _ref_count_;
	ObjectCacheTests* self;
	GMainLoop* main_loop;
	TestCache* cache;
	GeeSet* new_obj_set;
};

struct _Block4Data {
	int _ref_count_;
	ObjectCacheTests* self;
	GMainLoop* main_loop;
	TestCache* cache;
	GeeSet* new_obj_set;
};

struct _Block5Data {
	int _ref_count_;
	ObjectCacheTests* self;
	GMainLoop* main_loop;
	TestCache* cache;
	GeeSet* new_obj_set;
};

struct _Block6Data {
	int _ref_count_;
	ObjectCacheTests* self;
	GMainLoop* main_loop;
	TestCache* cache;
	GeeSet* new_obj_set;
};

struct _Block7Data {
	int _ref_count_;
	ObjectCacheTests* self;
	GMainLoop* main_loop;
	TestCache* cache;
	GeeSet* new_obj_set;
};

struct _Block8Data {
	int _ref_count_;
	ObjectCacheTests* self;
	GMainLoop* main_loop;
	TestCache* cache;
	GeeSet* new_obj_set;
};

struct _Block9Data {
	int _ref_count_;
	ObjectCacheTests* self;
	GMainLoop* main_loop;
	TestCache* cache;
	GeeSet* new_obj_set;
};

struct _Block10Data {
	int _ref_count_;
	ObjectCacheTests* self;
	GMainLoop* main_loop;
	TestCache* cache;
	GeeSet* new_obj_set;
};

struct _Block11Data {
	int _ref_count_;
	ObjectCacheTests* self;
	GMainLoop* main_loop;
	TestCache* cache;
	gint obj_count;
	GeeSet* new_obj_set;
};


static gpointer test_object_parent_class = NULL;
static gpointer test_cache_parent_class = NULL;
static gpointer object_cache_tests_parent_class = NULL;

gpointer test_object_ref (gpointer instance);
void test_object_unref (gpointer instance);
GParamSpec* param_spec_test_object (const gchar* name, const gchar* nick, const gchar* blurb, GType object_type, GParamFlags flags);
void value_set_test_object (GValue* value, gpointer v_object);
void value_take_test_object (GValue* value, gpointer v_object);
gpointer value_get_test_object (const GValue* value);
GType test_object_get_type (void) G_GNUC_CONST;
#define TEST_OBJECT_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), TYPE_TEST_OBJECT, TestObjectPrivate))
enum  {
	TEST_OBJECT_DUMMY_PROPERTY
};
TestObject* test_object_new (const gchar* my_string, guint my_int);
TestObject* test_object_construct (GType object_type, const gchar* my_string, guint my_int);
void test_object_set_my_string (TestObject* self, const gchar* value);
void test_object_set_my_int (TestObject* self, guint value);
const gchar* test_object_get_my_string (TestObject* self);
guint test_object_get_my_int (TestObject* self);
static void test_object_finalize (TestObject* obj);
GType test_cache_get_type (void) G_GNUC_CONST;
enum  {
	TEST_CACHE_DUMMY_PROPERTY
};
TestCache* test_cache_new (const gchar* id);
TestCache* test_cache_construct (GType object_type, const gchar* id);
static GVariantType* test_cache_real_get_serialised_object_type (FolksObjectCache* base, guint8 object_version);
static guint8 test_cache_real_get_serialised_object_version (FolksObjectCache* base);
static GVariant* test_cache_real_serialise_object (FolksObjectCache* base, TestObject* obj);
static TestObject* test_cache_real_deserialise_object (FolksObjectCache* base, GVariant* variant, guint8 object_version);
GType object_cache_tests_get_type (void) G_GNUC_CONST;
#define OBJECT_CACHE_TESTS_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), TYPE_OBJECT_CACHE_TESTS, ObjectCacheTestsPrivate))
enum  {
	OBJECT_CACHE_TESTS_DUMMY_PROPERTY
};
ObjectCacheTests* object_cache_tests_new (void);
ObjectCacheTests* object_cache_tests_construct (GType object_type);
void object_cache_tests_test_create (ObjectCacheTests* self);
static void _object_cache_tests_test_create_folks_test_case_test_method (gpointer self);
void object_cache_tests_test_store_objects (ObjectCacheTests* self);
static void _object_cache_tests_test_store_objects_folks_test_case_test_method (gpointer self);
void object_cache_tests_test_store_objects_empty (ObjectCacheTests* self);
static void _object_cache_tests_test_store_objects_empty_folks_test_case_test_method (gpointer self);
void object_cache_tests_test_load_objects (ObjectCacheTests* self);
static void _object_cache_tests_test_load_objects_folks_test_case_test_method (gpointer self);
void object_cache_tests_test_load_objects_empty (ObjectCacheTests* self);
static void _object_cache_tests_test_load_objects_empty_folks_test_case_test_method (gpointer self);
void object_cache_tests_test_load_objects_nonexistent (ObjectCacheTests* self);
static void _object_cache_tests_test_load_objects_nonexistent_folks_test_case_test_method (gpointer self);
void object_cache_tests_test_clear (ObjectCacheTests* self);
static void _object_cache_tests_test_clear_folks_test_case_test_method (gpointer self);
void object_cache_tests_test_clear_empty (ObjectCacheTests* self);
static void _object_cache_tests_test_clear_empty_folks_test_case_test_method (gpointer self);
void object_cache_tests_test_clear_nonexistent (ObjectCacheTests* self);
static void _object_cache_tests_test_clear_nonexistent_folks_test_case_test_method (gpointer self);
void object_cache_tests_test_store_objects_cancellation (ObjectCacheTests* self);
static void _object_cache_tests_test_store_objects_cancellation_folks_test_case_test_method (gpointer self);
void object_cache_tests_test_load_objects_cancellation (ObjectCacheTests* self);
static void _object_cache_tests_test_load_objects_cancellation_folks_test_case_test_method (gpointer self);
void object_cache_tests_test_stress (ObjectCacheTests* self);
static void _object_cache_tests_test_stress_folks_test_case_test_method (gpointer self);
static void object_cache_tests_real_set_up (FolksTestCase* base);
void _object_cache_tests_delete_cache_directory (ObjectCacheTests* self);
static void object_cache_tests_real_tear_down (FolksTestCase* base);
void _object_cache_tests_delete_directory (ObjectCacheTests* self, GFile* dir, GError** error);
static Block1Data* block1_data_ref (Block1Data* _data1_);
static void block1_data_unref (void * _userdata_);
static void __lambda4_ (Block1Data* _data1_, GObject* o, GAsyncResult* r);
static void ___lambda4__gasync_ready_callback (GObject* source_object, GAsyncResult* res, gpointer self);
static Block2Data* block2_data_ref (Block2Data* _data2_);
static void block2_data_unref (void * _userdata_);
static void __lambda5_ (Block2Data* _data2_, GObject* o, GAsyncResult* r);
static void ___lambda5__gasync_ready_callback (GObject* source_object, GAsyncResult* res, gpointer self);
static Block3Data* block3_data_ref (Block3Data* _data3_);
static void block3_data_unref (void * _userdata_);
static void __lambda6_ (Block3Data* _data3_, GObject* o, GAsyncResult* r);
static void ___lambda6__gasync_ready_callback (GObject* source_object, GAsyncResult* res, gpointer self);
static void __lambda7_ (Block3Data* _data3_, GObject* o, GAsyncResult* r);
static void ___lambda7__gasync_ready_callback (GObject* source_object, GAsyncResult* res, gpointer self);
static Block4Data* block4_data_ref (Block4Data* _data4_);
static void block4_data_unref (void * _userdata_);
static void __lambda8_ (Block4Data* _data4_, GObject* o, GAsyncResult* r);
static void ___lambda8__gasync_ready_callback (GObject* source_object, GAsyncResult* res, gpointer self);
static void __lambda9_ (Block4Data* _data4_, GObject* o, GAsyncResult* r);
static void ___lambda9__gasync_ready_callback (GObject* source_object, GAsyncResult* res, gpointer self);
static Block5Data* block5_data_ref (Block5Data* _data5_);
static void block5_data_unref (void * _userdata_);
static void __lambda10_ (Block5Data* _data5_, GObject* o, GAsyncResult* r);
static void ___lambda10__gasync_ready_callback (GObject* source_object, GAsyncResult* res, gpointer self);
static Block6Data* block6_data_ref (Block6Data* _data6_);
static void block6_data_unref (void * _userdata_);
static void __lambda11_ (Block6Data* _data6_, GObject* o, GAsyncResult* r);
static void ___lambda11__gasync_ready_callback (GObject* source_object, GAsyncResult* res, gpointer self);
static void __lambda12_ (Block6Data* _data6_, GObject* o, GAsyncResult* r);
static void ___lambda12__gasync_ready_callback (GObject* source_object, GAsyncResult* res, gpointer self);
static void __lambda13_ (Block6Data* _data6_, GObject* o, GAsyncResult* r);
static void ___lambda13__gasync_ready_callback (GObject* source_object, GAsyncResult* res, gpointer self);
static Block7Data* block7_data_ref (Block7Data* _data7_);
static void block7_data_unref (void * _userdata_);
static void __lambda14_ (Block7Data* _data7_, GObject* o, GAsyncResult* r);
static void ___lambda14__gasync_ready_callback (GObject* source_object, GAsyncResult* res, gpointer self);
static void __lambda15_ (Block7Data* _data7_, GObject* o, GAsyncResult* r);
static void ___lambda15__gasync_ready_callback (GObject* source_object, GAsyncResult* res, gpointer self);
static void __lambda16_ (Block7Data* _data7_, GObject* o, GAsyncResult* r);
static void ___lambda16__gasync_ready_callback (GObject* source_object, GAsyncResult* res, gpointer self);
static Block8Data* block8_data_ref (Block8Data* _data8_);
static void block8_data_unref (void * _userdata_);
static void __lambda17_ (Block8Data* _data8_, GObject* o, GAsyncResult* r);
static void ___lambda17__gasync_ready_callback (GObject* source_object, GAsyncResult* res, gpointer self);
static void __lambda18_ (Block8Data* _data8_, GObject* o, GAsyncResult* r);
static void ___lambda18__gasync_ready_callback (GObject* source_object, GAsyncResult* res, gpointer self);
static Block9Data* block9_data_ref (Block9Data* _data9_);
static void block9_data_unref (void * _userdata_);
static void __lambda19_ (Block9Data* _data9_, GObject* o, GAsyncResult* r);
static void ___lambda19__gasync_ready_callback (GObject* source_object, GAsyncResult* res, gpointer self);
static void __lambda20_ (Block9Data* _data9_, GObject* o, GAsyncResult* r);
static void ___lambda20__gasync_ready_callback (GObject* source_object, GAsyncResult* res, gpointer self);
static Block10Data* block10_data_ref (Block10Data* _data10_);
static void block10_data_unref (void * _userdata_);
static void __lambda21_ (Block10Data* _data10_, GObject* o, GAsyncResult* r);
static void ___lambda21__gasync_ready_callback (GObject* source_object, GAsyncResult* res, gpointer self);
static void __lambda22_ (Block10Data* _data10_, GObject* o, GAsyncResult* r);
static void ___lambda22__gasync_ready_callback (GObject* source_object, GAsyncResult* res, gpointer self);
static Block11Data* block11_data_ref (Block11Data* _data11_);
static void block11_data_unref (void * _userdata_);
static void __lambda23_ (Block11Data* _data11_, GObject* o, GAsyncResult* r);
static void ___lambda23__gasync_ready_callback (GObject* source_object, GAsyncResult* res, gpointer self);
static void __lambda24_ (Block11Data* _data11_, GObject* o, GAsyncResult* r);
static void ___lambda24__gasync_ready_callback (GObject* source_object, GAsyncResult* res, gpointer self);
static void object_cache_tests_finalize (GObject* obj);
gint _vala_main (gchar** args, int args_length1);
static void _vala_array_destroy (gpointer array, gint array_length, GDestroyNotify destroy_func);
static void _vala_array_free (gpointer array, gint array_length, GDestroyNotify destroy_func);


TestObject* test_object_construct (GType object_type, const gchar* my_string, guint my_int) {
	TestObject* self = NULL;
	const gchar* _tmp0_ = NULL;
	guint _tmp1_ = 0U;
#line 10 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	g_return_val_if_fail (my_string != NULL, NULL);
#line 10 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	self = (TestObject*) g_type_create_instance (object_type);
#line 12 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	_tmp0_ = my_string;
#line 12 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	test_object_set_my_string (self, _tmp0_);
#line 13 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	_tmp1_ = my_int;
#line 13 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	test_object_set_my_int (self, _tmp1_);
#line 10 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	return self;
#line 356 "object-cache.c"
}


TestObject* test_object_new (const gchar* my_string, guint my_int) {
#line 10 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	return test_object_construct (TYPE_TEST_OBJECT, my_string, my_int);
#line 363 "object-cache.c"
}


const gchar* test_object_get_my_string (TestObject* self) {
	const gchar* result;
	const gchar* _tmp0_ = NULL;
#line 7 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 7 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	_tmp0_ = self->priv->_my_string;
#line 7 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	result = _tmp0_;
#line 7 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	return result;
#line 378 "object-cache.c"
}


void test_object_set_my_string (TestObject* self, const gchar* value) {
	const gchar* _tmp0_ = NULL;
	gchar* _tmp1_ = NULL;
#line 7 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	g_return_if_fail (self != NULL);
#line 7 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	_tmp0_ = value;
#line 7 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	_tmp1_ = g_strdup (_tmp0_);
#line 7 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	_g_free0 (self->priv->_my_string);
#line 7 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	self->priv->_my_string = _tmp1_;
#line 395 "object-cache.c"
}


guint test_object_get_my_int (TestObject* self) {
	guint result;
	guint _tmp0_ = 0U;
#line 8 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	g_return_val_if_fail (self != NULL, 0U);
#line 8 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	_tmp0_ = self->priv->_my_int;
#line 8 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	result = _tmp0_;
#line 8 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	return result;
#line 410 "object-cache.c"
}


void test_object_set_my_int (TestObject* self, guint value) {
	guint _tmp0_ = 0U;
#line 8 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	g_return_if_fail (self != NULL);
#line 8 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	_tmp0_ = value;
#line 8 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	self->priv->_my_int = _tmp0_;
#line 422 "object-cache.c"
}


static void value_test_object_init (GValue* value) {
#line 5 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	value->data[0].v_pointer = NULL;
#line 429 "object-cache.c"
}


static void value_test_object_free_value (GValue* value) {
#line 5 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	if (value->data[0].v_pointer) {
#line 5 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
		test_object_unref (value->data[0].v_pointer);
#line 438 "object-cache.c"
	}
}


static void value_test_object_copy_value (const GValue* src_value, GValue* dest_value) {
#line 5 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	if (src_value->data[0].v_pointer) {
#line 5 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
		dest_value->data[0].v_pointer = test_object_ref (src_value->data[0].v_pointer);
#line 448 "object-cache.c"
	} else {
#line 5 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
		dest_value->data[0].v_pointer = NULL;
#line 452 "object-cache.c"
	}
}


static gpointer value_test_object_peek_pointer (const GValue* value) {
#line 5 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	return value->data[0].v_pointer;
#line 460 "object-cache.c"
}


static gchar* value_test_object_collect_value (GValue* value, guint n_collect_values, GTypeCValue* collect_values, guint collect_flags) {
#line 5 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	if (collect_values[0].v_pointer) {
#line 467 "object-cache.c"
		TestObject* object;
		object = collect_values[0].v_pointer;
#line 5 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
		if (object->parent_instance.g_class == NULL) {
#line 5 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
			return g_strconcat ("invalid unclassed object pointer for value type `", G_VALUE_TYPE_NAME (value), "'", NULL);
#line 474 "object-cache.c"
		} else if (!g_value_type_compatible (G_TYPE_FROM_INSTANCE (object), G_VALUE_TYPE (value))) {
#line 5 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
			return g_strconcat ("invalid object type `", g_type_name (G_TYPE_FROM_INSTANCE (object)), "' for value type `", G_VALUE_TYPE_NAME (value), "'", NULL);
#line 478 "object-cache.c"
		}
#line 5 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
		value->data[0].v_pointer = test_object_ref (object);
#line 482 "object-cache.c"
	} else {
#line 5 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
		value->data[0].v_pointer = NULL;
#line 486 "object-cache.c"
	}
#line 5 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	return NULL;
#line 490 "object-cache.c"
}


static gchar* value_test_object_lcopy_value (const GValue* value, guint n_collect_values, GTypeCValue* collect_values, guint collect_flags) {
	TestObject** object_p;
	object_p = collect_values[0].v_pointer;
#line 5 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	if (!object_p) {
#line 5 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
		return g_strdup_printf ("value location for `%s' passed as NULL", G_VALUE_TYPE_NAME (value));
#line 501 "object-cache.c"
	}
#line 5 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	if (!value->data[0].v_pointer) {
#line 5 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
		*object_p = NULL;
#line 507 "object-cache.c"
	} else if (collect_flags & G_VALUE_NOCOPY_CONTENTS) {
#line 5 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
		*object_p = value->data[0].v_pointer;
#line 511 "object-cache.c"
	} else {
#line 5 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
		*object_p = test_object_ref (value->data[0].v_pointer);
#line 515 "object-cache.c"
	}
#line 5 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	return NULL;
#line 519 "object-cache.c"
}


GParamSpec* param_spec_test_object (const gchar* name, const gchar* nick, const gchar* blurb, GType object_type, GParamFlags flags) {
	ParamSpecTestObject* spec;
#line 5 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	g_return_val_if_fail (g_type_is_a (object_type, TYPE_TEST_OBJECT), NULL);
#line 5 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	spec = g_param_spec_internal (G_TYPE_PARAM_OBJECT, name, nick, blurb, flags);
#line 5 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	G_PARAM_SPEC (spec)->value_type = object_type;
#line 5 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	return G_PARAM_SPEC (spec);
#line 533 "object-cache.c"
}


gpointer value_get_test_object (const GValue* value) {
#line 5 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	g_return_val_if_fail (G_TYPE_CHECK_VALUE_TYPE (value, TYPE_TEST_OBJECT), NULL);
#line 5 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	return value->data[0].v_pointer;
#line 542 "object-cache.c"
}


void value_set_test_object (GValue* value, gpointer v_object) {
	TestObject* old;
#line 5 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	g_return_if_fail (G_TYPE_CHECK_VALUE_TYPE (value, TYPE_TEST_OBJECT));
#line 5 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	old = value->data[0].v_pointer;
#line 5 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	if (v_object) {
#line 5 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
		g_return_if_fail (G_TYPE_CHECK_INSTANCE_TYPE (v_object, TYPE_TEST_OBJECT));
#line 5 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
		g_return_if_fail (g_value_type_compatible (G_TYPE_FROM_INSTANCE (v_object), G_VALUE_TYPE (value)));
#line 5 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
		value->data[0].v_pointer = v_object;
#line 5 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
		test_object_ref (value->data[0].v_pointer);
#line 562 "object-cache.c"
	} else {
#line 5 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
		value->data[0].v_pointer = NULL;
#line 566 "object-cache.c"
	}
#line 5 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	if (old) {
#line 5 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
		test_object_unref (old);
#line 572 "object-cache.c"
	}
}


void value_take_test_object (GValue* value, gpointer v_object) {
	TestObject* old;
#line 5 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	g_return_if_fail (G_TYPE_CHECK_VALUE_TYPE (value, TYPE_TEST_OBJECT));
#line 5 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	old = value->data[0].v_pointer;
#line 5 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	if (v_object) {
#line 5 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
		g_return_if_fail (G_TYPE_CHECK_INSTANCE_TYPE (v_object, TYPE_TEST_OBJECT));
#line 5 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
		g_return_if_fail (g_value_type_compatible (G_TYPE_FROM_INSTANCE (v_object), G_VALUE_TYPE (value)));
#line 5 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
		value->data[0].v_pointer = v_object;
#line 591 "object-cache.c"
	} else {
#line 5 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
		value->data[0].v_pointer = NULL;
#line 595 "object-cache.c"
	}
#line 5 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	if (old) {
#line 5 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
		test_object_unref (old);
#line 601 "object-cache.c"
	}
}


static void test_object_class_init (TestObjectClass * klass) {
#line 5 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	test_object_parent_class = g_type_class_peek_parent (klass);
#line 5 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	((TestObjectClass *) klass)->finalize = test_object_finalize;
#line 5 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	g_type_class_add_private (klass, sizeof (TestObjectPrivate));
#line 613 "object-cache.c"
}


static void test_object_instance_init (TestObject * self) {
#line 5 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	self->priv = TEST_OBJECT_GET_PRIVATE (self);
#line 5 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	self->ref_count = 1;
#line 622 "object-cache.c"
}


static void test_object_finalize (TestObject* obj) {
	TestObject * self;
#line 5 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, TYPE_TEST_OBJECT, TestObject);
#line 5 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	g_signal_handlers_destroy (self);
#line 7 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	_g_free0 (self->priv->_my_string);
#line 634 "object-cache.c"
}


GType test_object_get_type (void) {
	static volatile gsize test_object_type_id__volatile = 0;
	if (g_once_init_enter (&test_object_type_id__volatile)) {
		static const GTypeValueTable g_define_type_value_table = { value_test_object_init, value_test_object_free_value, value_test_object_copy_value, value_test_object_peek_pointer, "p", value_test_object_collect_value, "p", value_test_object_lcopy_value };
		static const GTypeInfo g_define_type_info = { sizeof (TestObjectClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) test_object_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (TestObject), 0, (GInstanceInitFunc) test_object_instance_init, &g_define_type_value_table };
		static const GTypeFundamentalInfo g_define_type_fundamental_info = { (G_TYPE_FLAG_CLASSED | G_TYPE_FLAG_INSTANTIATABLE | G_TYPE_FLAG_DERIVABLE | G_TYPE_FLAG_DEEP_DERIVABLE) };
		GType test_object_type_id;
		test_object_type_id = g_type_register_fundamental (g_type_fundamental_next (), "TestObject", &g_define_type_info, &g_define_type_fundamental_info, 0);
		g_once_init_leave (&test_object_type_id__volatile, test_object_type_id);
	}
	return test_object_type_id__volatile;
}


gpointer test_object_ref (gpointer instance) {
	TestObject* self;
	self = instance;
#line 5 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	g_atomic_int_inc (&self->ref_count);
#line 5 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	return instance;
#line 659 "object-cache.c"
}


void test_object_unref (gpointer instance) {
	TestObject* self;
	self = instance;
#line 5 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	if (g_atomic_int_dec_and_test (&self->ref_count)) {
#line 5 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
		TEST_OBJECT_GET_CLASS (self)->finalize (self);
#line 5 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
		g_type_free_instance ((GTypeInstance *) self);
#line 672 "object-cache.c"
	}
}


TestCache* test_cache_construct (GType object_type, const gchar* id) {
	TestCache * self = NULL;
	const gchar* _tmp0_ = NULL;
#line 19 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	g_return_val_if_fail (id != NULL, NULL);
#line 21 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	_tmp0_ = id;
#line 21 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	self = (TestCache*) folks_object_cache_construct (object_type, TYPE_TEST_OBJECT, (GBoxedCopyFunc) test_object_ref, test_object_unref, "test", _tmp0_);
#line 19 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	return self;
#line 688 "object-cache.c"
}


TestCache* test_cache_new (const gchar* id) {
#line 19 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	return test_cache_construct (TYPE_TEST_CACHE, id);
#line 695 "object-cache.c"
}


static gpointer _g_variant_type_copy0 (gpointer self) {
#line 27 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	return self ? g_variant_type_copy (self) : NULL;
#line 702 "object-cache.c"
}


static GVariantType* test_cache_real_get_serialised_object_type (FolksObjectCache* base, guint8 object_version) {
	TestCache * self;
	GVariantType* result = NULL;
	const GVariantType* _tmp0_ = NULL;
	GVariantType* _tmp1_ = NULL;
	const GVariantType* _tmp2_ = NULL;
	GVariantType* _tmp3_ = NULL;
	GVariantType** _tmp4_ = NULL;
	GVariantType** _tmp5_ = NULL;
	gint _tmp5__length1 = 0;
	GVariantType* _tmp6_ = NULL;
	GVariantType* _tmp7_ = NULL;
#line 24 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	self = (TestCache*) base;
#line 27 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	_tmp0_ = G_VARIANT_TYPE_STRING;
#line 27 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	_tmp1_ = _g_variant_type_copy0 (_tmp0_);
#line 27 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	_tmp2_ = G_VARIANT_TYPE_UINT32;
#line 27 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	_tmp3_ = _g_variant_type_copy0 (_tmp2_);
#line 27 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	_tmp4_ = g_new0 (GVariantType*, 2 + 1);
#line 27 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	_tmp4_[0] = _tmp1_;
#line 27 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	_tmp4_[1] = _tmp3_;
#line 27 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	_tmp5_ = _tmp4_;
#line 27 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	_tmp5__length1 = 2;
#line 27 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	_tmp6_ = g_variant_type_new_tuple (_tmp5_, 2);
#line 27 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	_tmp7_ = _tmp6_;
#line 27 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	_tmp5_ = (_vala_array_free (_tmp5_, _tmp5__length1, (GDestroyNotify) g_variant_type_free), NULL);
#line 27 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	result = _tmp7_;
#line 27 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	return result;
#line 748 "object-cache.c"
}


static guint8 test_cache_real_get_serialised_object_version (FolksObjectCache* base) {
	TestCache * self;
	guint8 result = 0U;
#line 33 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	self = (TestCache*) base;
#line 35 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	result = (guint8) 1;
#line 35 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	return result;
#line 761 "object-cache.c"
}


static GVariant* test_cache_real_serialise_object (FolksObjectCache* base, TestObject* obj) {
	TestCache * self;
	GVariant* result = NULL;
	TestObject* _tmp0_ = NULL;
	const gchar* _tmp1_ = NULL;
	const gchar* _tmp2_ = NULL;
	GVariant* _tmp3_ = NULL;
	TestObject* _tmp4_ = NULL;
	guint _tmp5_ = 0U;
	guint _tmp6_ = 0U;
	GVariant* _tmp7_ = NULL;
	GVariant** _tmp8_ = NULL;
	GVariant** _tmp9_ = NULL;
	gint _tmp9__length1 = 0;
	GVariant* _tmp10_ = NULL;
	GVariant* _tmp11_ = NULL;
#line 38 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	self = (TestCache*) base;
#line 38 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	g_return_val_if_fail (obj != NULL, NULL);
#line 40 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	_tmp0_ = obj;
#line 40 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	_tmp1_ = test_object_get_my_string (_tmp0_);
#line 40 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	_tmp2_ = _tmp1_;
#line 40 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	_tmp3_ = g_variant_new_string (_tmp2_);
#line 40 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	g_variant_ref_sink (_tmp3_);
#line 40 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	_tmp4_ = obj;
#line 40 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	_tmp5_ = test_object_get_my_int (_tmp4_);
#line 40 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	_tmp6_ = _tmp5_;
#line 40 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	_tmp7_ = g_variant_new_uint32 ((guint32) _tmp6_);
#line 40 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	g_variant_ref_sink (_tmp7_);
#line 40 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	_tmp8_ = g_new0 (GVariant*, 2 + 1);
#line 40 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	_tmp8_[0] = _tmp3_;
#line 40 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	_tmp8_[1] = _tmp7_;
#line 40 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	_tmp9_ = _tmp8_;
#line 40 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	_tmp9__length1 = 2;
#line 40 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	_tmp10_ = g_variant_new_tuple (_tmp9_, 2);
#line 40 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	g_variant_ref_sink (_tmp10_);
#line 40 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	_tmp11_ = _tmp10_;
#line 40 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	_tmp9_ = (_vala_array_free (_tmp9_, _tmp9__length1, (GDestroyNotify) g_variant_unref), NULL);
#line 40 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	result = _tmp11_;
#line 40 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	return result;
#line 827 "object-cache.c"
}


static TestObject* test_cache_real_deserialise_object (FolksObjectCache* base, GVariant* variant, guint8 object_version) {
	TestCache * self;
	TestObject* result = NULL;
	gchar* my_string = NULL;
	GVariant* _tmp0_ = NULL;
	GVariant* _tmp1_ = NULL;
	GVariant* _tmp2_ = NULL;
	const gchar* _tmp3_ = NULL;
	gchar* _tmp4_ = NULL;
	gchar* _tmp5_ = NULL;
	guint32 my_int = 0U;
	GVariant* _tmp6_ = NULL;
	GVariant* _tmp7_ = NULL;
	GVariant* _tmp8_ = NULL;
	guint32 _tmp9_ = 0U;
	guint32 _tmp10_ = 0U;
	TestObject* _tmp11_ = NULL;
#line 46 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	self = (TestCache*) base;
#line 46 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	g_return_val_if_fail (variant != NULL, NULL);
#line 50 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	_tmp0_ = variant;
#line 50 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	_tmp1_ = g_variant_get_child_value (_tmp0_, (gsize) 0);
#line 50 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	_tmp2_ = _tmp1_;
#line 50 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	_tmp3_ = g_variant_get_string (_tmp2_, NULL);
#line 50 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	_tmp4_ = g_strdup (_tmp3_);
#line 50 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	_tmp5_ = _tmp4_;
#line 50 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	_g_variant_unref0 (_tmp2_);
#line 50 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	my_string = _tmp5_;
#line 51 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	_tmp6_ = variant;
#line 51 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	_tmp7_ = g_variant_get_child_value (_tmp6_, (gsize) 1);
#line 51 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	_tmp8_ = _tmp7_;
#line 51 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	_tmp9_ = g_variant_get_uint32 (_tmp8_);
#line 51 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	_tmp10_ = _tmp9_;
#line 51 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	_g_variant_unref0 (_tmp8_);
#line 51 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	my_int = _tmp10_;
#line 53 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	_tmp11_ = test_object_new (my_string, (guint) my_int);
#line 53 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	result = _tmp11_;
#line 53 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	_g_free0 (my_string);
#line 53 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	return result;
#line 890 "object-cache.c"
}


static void test_cache_class_init (TestCacheClass * klass) {
#line 17 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	test_cache_parent_class = g_type_class_peek_parent (klass);
#line 17 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	((FolksObjectCacheClass *) klass)->get_serialised_object_type = test_cache_real_get_serialised_object_type;
#line 17 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	((FolksObjectCacheClass *) klass)->get_serialised_object_version = test_cache_real_get_serialised_object_version;
#line 17 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	((FolksObjectCacheClass *) klass)->serialise_object = test_cache_real_serialise_object;
#line 17 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	((FolksObjectCacheClass *) klass)->deserialise_object = test_cache_real_deserialise_object;
#line 905 "object-cache.c"
}


static void test_cache_instance_init (TestCache * self) {
}


GType test_cache_get_type (void) {
	static volatile gsize test_cache_type_id__volatile = 0;
	if (g_once_init_enter (&test_cache_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (TestCacheClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) test_cache_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (TestCache), 0, (GInstanceInitFunc) test_cache_instance_init, NULL };
		GType test_cache_type_id;
		test_cache_type_id = g_type_register_static (FOLKS_TYPE_OBJECT_CACHE, "TestCache", &g_define_type_info, 0);
		g_once_init_leave (&test_cache_type_id__volatile, test_cache_type_id);
	}
	return test_cache_type_id__volatile;
}


static void _object_cache_tests_test_create_folks_test_case_test_method (gpointer self) {
#line 74 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	object_cache_tests_test_create ((ObjectCacheTests*) self);
#line 928 "object-cache.c"
}


static void _object_cache_tests_test_store_objects_folks_test_case_test_method (gpointer self) {
#line 75 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	object_cache_tests_test_store_objects ((ObjectCacheTests*) self);
#line 935 "object-cache.c"
}


static void _object_cache_tests_test_store_objects_empty_folks_test_case_test_method (gpointer self) {
#line 76 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	object_cache_tests_test_store_objects_empty ((ObjectCacheTests*) self);
#line 942 "object-cache.c"
}


static void _object_cache_tests_test_load_objects_folks_test_case_test_method (gpointer self) {
#line 77 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	object_cache_tests_test_load_objects ((ObjectCacheTests*) self);
#line 949 "object-cache.c"
}


static void _object_cache_tests_test_load_objects_empty_folks_test_case_test_method (gpointer self) {
#line 78 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	object_cache_tests_test_load_objects_empty ((ObjectCacheTests*) self);
#line 956 "object-cache.c"
}


static void _object_cache_tests_test_load_objects_nonexistent_folks_test_case_test_method (gpointer self) {
#line 79 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	object_cache_tests_test_load_objects_nonexistent ((ObjectCacheTests*) self);
#line 963 "object-cache.c"
}


static void _object_cache_tests_test_clear_folks_test_case_test_method (gpointer self) {
#line 81 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	object_cache_tests_test_clear ((ObjectCacheTests*) self);
#line 970 "object-cache.c"
}


static void _object_cache_tests_test_clear_empty_folks_test_case_test_method (gpointer self) {
#line 82 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	object_cache_tests_test_clear_empty ((ObjectCacheTests*) self);
#line 977 "object-cache.c"
}


static void _object_cache_tests_test_clear_nonexistent_folks_test_case_test_method (gpointer self) {
#line 83 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	object_cache_tests_test_clear_nonexistent ((ObjectCacheTests*) self);
#line 984 "object-cache.c"
}


static void _object_cache_tests_test_store_objects_cancellation_folks_test_case_test_method (gpointer self) {
#line 86 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	object_cache_tests_test_store_objects_cancellation ((ObjectCacheTests*) self);
#line 991 "object-cache.c"
}


static void _object_cache_tests_test_load_objects_cancellation_folks_test_case_test_method (gpointer self) {
#line 88 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	object_cache_tests_test_load_objects_cancellation ((ObjectCacheTests*) self);
#line 998 "object-cache.c"
}


static void _object_cache_tests_test_stress_folks_test_case_test_method (gpointer self) {
#line 92 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	object_cache_tests_test_stress ((ObjectCacheTests*) self);
#line 1005 "object-cache.c"
}


ObjectCacheTests* object_cache_tests_construct (GType object_type) {
	ObjectCacheTests * self = NULL;
	gchar* tmp_path = NULL;
	const gchar* _tmp0_ = NULL;
	gchar* _tmp1_ = NULL;
	const gchar* _tmp2_ = NULL;
	GFile* _tmp3_ = NULL;
#line 64 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	self = (ObjectCacheTests*) folks_test_case_construct (object_type, "ObjectCache");
#line 68 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	_tmp0_ = g_get_tmp_dir ();
#line 68 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	_tmp1_ = g_strconcat (_tmp0_, "/folks-object-cache-tests", NULL);
#line 68 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	tmp_path = _tmp1_;
#line 69 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	g_setenv ("XDG_CACHE_HOME", tmp_path, TRUE);
#line 70 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	_tmp2_ = g_get_user_cache_dir ();
#line 70 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	_vala_assert (g_strcmp0 (_tmp2_, tmp_path) == 0, "Environment.get_user_cache_dir () == tmp_path");
#line 71 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	_tmp3_ = g_file_new_for_path (tmp_path);
#line 71 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	_g_object_unref0 (self->priv->_cache_dir);
#line 71 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	self->priv->_cache_dir = _tmp3_;
#line 74 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	folks_test_case_add_test ((FolksTestCase*) self, "create", _object_cache_tests_test_create_folks_test_case_test_method, g_object_ref (self), g_object_unref);
#line 75 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	folks_test_case_add_test ((FolksTestCase*) self, "store-objects", _object_cache_tests_test_store_objects_folks_test_case_test_method, g_object_ref (self), g_object_unref);
#line 76 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	folks_test_case_add_test ((FolksTestCase*) self, "store-objects-empty", _object_cache_tests_test_store_objects_empty_folks_test_case_test_method, g_object_ref (self), g_object_unref);
#line 77 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	folks_test_case_add_test ((FolksTestCase*) self, "load-objects", _object_cache_tests_test_load_objects_folks_test_case_test_method, g_object_ref (self), g_object_unref);
#line 78 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	folks_test_case_add_test ((FolksTestCase*) self, "load-objects-empty", _object_cache_tests_test_load_objects_empty_folks_test_case_test_method, g_object_ref (self), g_object_unref);
#line 79 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	folks_test_case_add_test ((FolksTestCase*) self, "load-objects-nonexistent", _object_cache_tests_test_load_objects_nonexistent_folks_test_case_test_method, g_object_ref (self), g_object_unref);
#line 81 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	folks_test_case_add_test ((FolksTestCase*) self, "clear", _object_cache_tests_test_clear_folks_test_case_test_method, g_object_ref (self), g_object_unref);
#line 82 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	folks_test_case_add_test ((FolksTestCase*) self, "clear-empty", _object_cache_tests_test_clear_empty_folks_test_case_test_method, g_object_ref (self), g_object_unref);
#line 83 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	folks_test_case_add_test ((FolksTestCase*) self, "clear-nonexistent", _object_cache_tests_test_clear_nonexistent_folks_test_case_test_method, g_object_ref (self), g_object_unref);
#line 86 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	folks_test_case_add_test ((FolksTestCase*) self, "store-objects-cancellation", _object_cache_tests_test_store_objects_cancellation_folks_test_case_test_method, g_object_ref (self), g_object_unref);
#line 88 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	folks_test_case_add_test ((FolksTestCase*) self, "load-objects-cancellation", _object_cache_tests_test_load_objects_cancellation_folks_test_case_test_method, g_object_ref (self), g_object_unref);
#line 92 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	folks_test_case_add_test ((FolksTestCase*) self, "stress", _object_cache_tests_test_stress_folks_test_case_test_method, g_object_ref (self), g_object_unref);
#line 62 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	_g_free0 (tmp_path);
#line 62 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	return self;
#line 1064 "object-cache.c"
}


ObjectCacheTests* object_cache_tests_new (void) {
#line 62 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	return object_cache_tests_construct (TYPE_OBJECT_CACHE_TESTS);
#line 1071 "object-cache.c"
}


static void object_cache_tests_real_set_up (FolksTestCase* base) {
	ObjectCacheTests * self;
#line 95 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	self = (ObjectCacheTests*) base;
#line 97 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	FOLKS_TEST_CASE_CLASS (object_cache_tests_parent_class)->set_up (G_TYPE_CHECK_INSTANCE_CAST (self, FOLKS_TYPE_TEST_CASE, FolksTestCase));
#line 98 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	_object_cache_tests_delete_cache_directory (self);
#line 1083 "object-cache.c"
}


static void object_cache_tests_real_tear_down (FolksTestCase* base) {
	ObjectCacheTests * self;
#line 101 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	self = (ObjectCacheTests*) base;
#line 103 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	_object_cache_tests_delete_cache_directory (self);
#line 104 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	FOLKS_TEST_CASE_CLASS (object_cache_tests_parent_class)->tear_down (G_TYPE_CHECK_INSTANCE_CAST (self, FOLKS_TYPE_TEST_CASE, FolksTestCase));
#line 1095 "object-cache.c"
}


void _object_cache_tests_delete_directory (ObjectCacheTests* self, GFile* dir, GError** error) {
	GFileEnumerator* enumerator = NULL;
	GFile* _tmp0_ = NULL;
	GFileEnumerator* _tmp1_ = NULL;
	GFileInfo* file_info = NULL;
	GFileEnumerator* _tmp2_ = NULL;
	GFileInfo* _tmp3_ = NULL;
	GFileEnumerator* _tmp17_ = NULL;
	GFile* _tmp18_ = NULL;
	GError * _inner_error_ = NULL;
#line 107 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	g_return_if_fail (self != NULL);
#line 107 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	g_return_if_fail (dir != NULL);
#line 110 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	_tmp0_ = dir;
#line 110 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	_tmp1_ = g_file_enumerate_children (_tmp0_, G_FILE_ATTRIBUTE_STANDARD_NAME, G_FILE_QUERY_INFO_NONE, NULL, &_inner_error_);
#line 110 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	enumerator = _tmp1_;
#line 110 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 110 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
		g_propagate_error (error, _inner_error_);
#line 110 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
		return;
#line 1125 "object-cache.c"
	}
#line 114 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	_tmp2_ = enumerator;
#line 114 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	_tmp3_ = g_file_enumerator_next_file (_tmp2_, NULL, &_inner_error_);
#line 114 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	file_info = _tmp3_;
#line 114 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 114 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
		g_propagate_error (error, _inner_error_);
#line 114 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
		_g_object_unref0 (enumerator);
#line 114 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
		return;
#line 1141 "object-cache.c"
	}
#line 115 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	while (TRUE) {
#line 1145 "object-cache.c"
		GFileInfo* _tmp4_ = NULL;
		GFile* child_file = NULL;
		GFile* _tmp5_ = NULL;
		GFileInfo* _tmp6_ = NULL;
		const gchar* _tmp7_ = NULL;
		GFile* _tmp8_ = NULL;
		GFile* _tmp9_ = NULL;
		GFileType _tmp10_ = 0;
		GFileInfo* _tmp13_ = NULL;
		GFileEnumerator* _tmp14_ = NULL;
		GFileInfo* _tmp15_ = NULL;
		GFileInfo* _tmp16_ = NULL;
#line 115 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
		_tmp4_ = file_info;
#line 115 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
		if (!(_tmp4_ != NULL)) {
#line 115 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
			break;
#line 1164 "object-cache.c"
		}
#line 117 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
		_tmp5_ = dir;
#line 117 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
		_tmp6_ = file_info;
#line 117 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
		_tmp7_ = g_file_info_get_name (_tmp6_);
#line 117 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
		_tmp8_ = g_file_get_child (_tmp5_, _tmp7_);
#line 117 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
		child_file = _tmp8_;
#line 119 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
		_tmp9_ = child_file;
#line 119 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
		_tmp10_ = g_file_query_file_type (_tmp9_, G_FILE_QUERY_INFO_NONE, NULL);
#line 119 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
		if (_tmp10_ == G_FILE_TYPE_DIRECTORY) {
#line 1182 "object-cache.c"
			GFile* _tmp11_ = NULL;
#line 122 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
			_tmp11_ = child_file;
#line 122 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
			_object_cache_tests_delete_directory (self, _tmp11_, &_inner_error_);
#line 122 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
			if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 122 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
				g_propagate_error (error, _inner_error_);
#line 122 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
				_g_object_unref0 (child_file);
#line 122 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
				_g_object_unref0 (file_info);
#line 122 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
				_g_object_unref0 (enumerator);
#line 122 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
				return;
#line 1200 "object-cache.c"
			}
		} else {
			GFile* _tmp12_ = NULL;
#line 126 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
			_tmp12_ = child_file;
#line 126 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
			g_file_delete (_tmp12_, NULL, &_inner_error_);
#line 126 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
			if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 126 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
				g_propagate_error (error, _inner_error_);
#line 126 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
				_g_object_unref0 (child_file);
#line 126 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
				_g_object_unref0 (file_info);
#line 126 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
				_g_object_unref0 (enumerator);
#line 126 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
				return;
#line 1220 "object-cache.c"
			}
		}
#line 129 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
		_tmp14_ = enumerator;
#line 129 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
		_tmp15_ = g_file_enumerator_next_file (_tmp14_, NULL, &_inner_error_);
#line 129 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
		_tmp13_ = _tmp15_;
#line 129 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 129 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
			g_propagate_error (error, _inner_error_);
#line 129 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
			_g_object_unref0 (child_file);
#line 129 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
			_g_object_unref0 (file_info);
#line 129 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
			_g_object_unref0 (enumerator);
#line 129 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
			return;
#line 1241 "object-cache.c"
		}
#line 129 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
		_tmp16_ = _tmp13_;
#line 129 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
		_tmp13_ = NULL;
#line 129 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
		_g_object_unref0 (file_info);
#line 129 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
		file_info = _tmp16_;
#line 115 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
		_g_object_unref0 (_tmp13_);
#line 115 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
		_g_object_unref0 (child_file);
#line 1255 "object-cache.c"
	}
#line 131 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	_tmp17_ = enumerator;
#line 131 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	g_file_enumerator_close (_tmp17_, NULL, &_inner_error_);
#line 131 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 131 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
		g_propagate_error (error, _inner_error_);
#line 131 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
		_g_object_unref0 (file_info);
#line 131 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
		_g_object_unref0 (enumerator);
#line 131 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
		return;
#line 1271 "object-cache.c"
	}
#line 134 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	_tmp18_ = dir;
#line 134 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	g_file_delete (_tmp18_, NULL, &_inner_error_);
#line 134 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 134 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
		g_propagate_error (error, _inner_error_);
#line 134 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
		_g_object_unref0 (file_info);
#line 134 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
		_g_object_unref0 (enumerator);
#line 134 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
		return;
#line 1287 "object-cache.c"
	}
#line 107 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	_g_object_unref0 (file_info);
#line 107 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	_g_object_unref0 (enumerator);
#line 1293 "object-cache.c"
}


void _object_cache_tests_delete_cache_directory (ObjectCacheTests* self) {
	GError * _inner_error_ = NULL;
#line 137 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	g_return_if_fail (self != NULL);
#line 1301 "object-cache.c"
	{
		GFile* _tmp0_ = NULL;
#line 141 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
		_tmp0_ = self->priv->_cache_dir;
#line 141 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
		_object_cache_tests_delete_directory (self, _tmp0_, &_inner_error_);
#line 141 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 1310 "object-cache.c"
			goto __catch0_g_error;
		}
	}
	goto __finally0;
	__catch0_g_error:
	{
		GError* e = NULL;
#line 139 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
		e = _inner_error_;
#line 139 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
		_inner_error_ = NULL;
#line 139 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
		_g_error_free0 (e);
#line 1324 "object-cache.c"
	}
	__finally0:
#line 139 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 139 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 139 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
		g_clear_error (&_inner_error_);
#line 139 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
		return;
#line 1335 "object-cache.c"
	}
}


void object_cache_tests_test_create (ObjectCacheTests* self) {
	TestCache* cache = NULL;
	TestCache* _tmp0_ = NULL;
#line 149 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	g_return_if_fail (self != NULL);
#line 152 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	_tmp0_ = test_cache_new ("test-create");
#line 152 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	cache = _tmp0_;
#line 154 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	_vala_assert (cache != NULL, "cache != null");
#line 149 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	_g_object_unref0 (cache);
#line 1353 "object-cache.c"
}


static Block1Data* block1_data_ref (Block1Data* _data1_) {
#line 157 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	g_atomic_int_inc (&_data1_->_ref_count_);
#line 157 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	return _data1_;
#line 1362 "object-cache.c"
}


static void block1_data_unref (void * _userdata_) {
	Block1Data* _data1_;
	_data1_ = (Block1Data*) _userdata_;
#line 157 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	if (g_atomic_int_dec_and_test (&_data1_->_ref_count_)) {
#line 1371 "object-cache.c"
		ObjectCacheTests* self;
#line 157 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
		self = _data1_->self;
#line 157 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
		_g_object_unref0 (_data1_->cache);
#line 157 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
		_g_main_loop_unref0 (_data1_->main_loop);
#line 157 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
		_g_object_unref0 (self);
#line 157 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
		g_slice_free (Block1Data, _data1_);
#line 1383 "object-cache.c"
	}
}


static void __lambda4_ (Block1Data* _data1_, GObject* o, GAsyncResult* r) {
	ObjectCacheTests* self;
	GAsyncResult* _tmp0_ = NULL;
#line 168 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	self = _data1_->self;
#line 168 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	g_return_if_fail (r != NULL);
#line 170 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	_tmp0_ = r;
#line 170 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	folks_object_cache_store_objects_finish ((FolksObjectCache*) _data1_->cache, _tmp0_);
#line 171 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	g_main_loop_quit (_data1_->main_loop);
#line 1401 "object-cache.c"
}


static void ___lambda4__gasync_ready_callback (GObject* source_object, GAsyncResult* res, gpointer self) {
#line 168 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	__lambda4_ (self, source_object, res);
#line 168 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	block1_data_unref (self);
#line 1410 "object-cache.c"
}


void object_cache_tests_test_store_objects (ObjectCacheTests* self) {
	Block1Data* _data1_;
	GMainLoop* _tmp0_ = NULL;
	TestCache* _tmp1_ = NULL;
	GeeHashSet* obj_set = NULL;
	GeeHashSet* _tmp2_ = NULL;
	TestObject* _tmp3_ = NULL;
	TestObject* _tmp4_ = NULL;
	TestObject* _tmp5_ = NULL;
	TestObject* _tmp6_ = NULL;
	TestObject* _tmp7_ = NULL;
	TestObject* _tmp8_ = NULL;
	TestObject* _tmp9_ = NULL;
	TestObject* _tmp10_ = NULL;
#line 157 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	g_return_if_fail (self != NULL);
#line 157 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	_data1_ = g_slice_new0 (Block1Data);
#line 157 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	_data1_->_ref_count_ = 1;
#line 157 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	_data1_->self = g_object_ref (self);
#line 159 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	_tmp0_ = g_main_loop_new (NULL, FALSE);
#line 159 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	_data1_->main_loop = _tmp0_;
#line 160 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	_tmp1_ = test_cache_new ("test-store-objects");
#line 160 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	_data1_->cache = _tmp1_;
#line 162 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	_tmp2_ = gee_hash_set_new (TYPE_TEST_OBJECT, (GBoxedCopyFunc) test_object_ref, test_object_unref, NULL, NULL, NULL, NULL, NULL, NULL);
#line 162 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	obj_set = _tmp2_;
#line 163 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	_tmp3_ = test_object_new ("Foo", (guint) 1);
#line 163 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	_tmp4_ = _tmp3_;
#line 163 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	gee_abstract_collection_add ((GeeAbstractCollection*) obj_set, _tmp4_);
#line 163 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	_test_object_unref0 (_tmp4_);
#line 164 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	_tmp5_ = test_object_new ("Bar", (guint) 2);
#line 164 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	_tmp6_ = _tmp5_;
#line 164 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	gee_abstract_collection_add ((GeeAbstractCollection*) obj_set, _tmp6_);
#line 164 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	_test_object_unref0 (_tmp6_);
#line 165 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	_tmp7_ = test_object_new ("De", (guint) 3);
#line 165 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	_tmp8_ = _tmp7_;
#line 165 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	gee_abstract_collection_add ((GeeAbstractCollection*) obj_set, _tmp8_);
#line 165 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	_test_object_unref0 (_tmp8_);
#line 166 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	_tmp9_ = test_object_new ("Baz", (guint) 4);
#line 166 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	_tmp10_ = _tmp9_;
#line 166 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	gee_abstract_collection_add ((GeeAbstractCollection*) obj_set, _tmp10_);
#line 166 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	_test_object_unref0 (_tmp10_);
#line 168 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	folks_object_cache_store_objects ((FolksObjectCache*) _data1_->cache, (GeeSet*) obj_set, NULL, ___lambda4__gasync_ready_callback, block1_data_ref (_data1_));
#line 174 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	g_main_loop_run (_data1_->main_loop);
#line 157 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	_g_object_unref0 (obj_set);
#line 157 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	block1_data_unref (_data1_);
#line 157 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	_data1_ = NULL;
#line 1490 "object-cache.c"
}


static Block2Data* block2_data_ref (Block2Data* _data2_) {
#line 177 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	g_atomic_int_inc (&_data2_->_ref_count_);
#line 177 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	return _data2_;
#line 1499 "object-cache.c"
}


static void block2_data_unref (void * _userdata_) {
	Block2Data* _data2_;
	_data2_ = (Block2Data*) _userdata_;
#line 177 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	if (g_atomic_int_dec_and_test (&_data2_->_ref_count_)) {
#line 1508 "object-cache.c"
		ObjectCacheTests* self;
#line 177 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
		self = _data2_->self;
#line 177 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
		_g_object_unref0 (_data2_->cache);
#line 177 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
		_g_main_loop_unref0 (_data2_->main_loop);
#line 177 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
		_g_object_unref0 (self);
#line 177 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
		g_slice_free (Block2Data, _data2_);
#line 1520 "object-cache.c"
	}
}


static void __lambda5_ (Block2Data* _data2_, GObject* o, GAsyncResult* r) {
	ObjectCacheTests* self;
	GAsyncResult* _tmp0_ = NULL;
#line 182 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	self = _data2_->self;
#line 182 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	g_return_if_fail (r != NULL);
#line 184 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	_tmp0_ = r;
#line 184 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	folks_object_cache_store_objects_finish ((FolksObjectCache*) _data2_->cache, _tmp0_);
#line 185 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	g_main_loop_quit (_data2_->main_loop);
#line 1538 "object-cache.c"
}


static void ___lambda5__gasync_ready_callback (GObject* source_object, GAsyncResult* res, gpointer self) {
#line 182 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	__lambda5_ (self, source_object, res);
#line 182 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	block2_data_unref (self);
#line 1547 "object-cache.c"
}


void object_cache_tests_test_store_objects_empty (ObjectCacheTests* self) {
	Block2Data* _data2_;
	GMainLoop* _tmp0_ = NULL;
	TestCache* _tmp1_ = NULL;
	GeeHashSet* _tmp2_ = NULL;
	GeeHashSet* _tmp3_ = NULL;
#line 177 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	g_return_if_fail (self != NULL);
#line 177 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	_data2_ = g_slice_new0 (Block2Data);
#line 177 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	_data2_->_ref_count_ = 1;
#line 177 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	_data2_->self = g_object_ref (self);
#line 179 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	_tmp0_ = g_main_loop_new (NULL, FALSE);
#line 179 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	_data2_->main_loop = _tmp0_;
#line 180 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	_tmp1_ = test_cache_new ("test-store-objects-empty");
#line 180 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	_data2_->cache = _tmp1_;
#line 182 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	_tmp2_ = gee_hash_set_new (TYPE_TEST_OBJECT, (GBoxedCopyFunc) test_object_ref, test_object_unref, NULL, NULL, NULL, NULL, NULL, NULL);
#line 182 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	_tmp3_ = _tmp2_;
#line 182 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	folks_object_cache_store_objects ((FolksObjectCache*) _data2_->cache, (GeeSet*) _tmp3_, NULL, ___lambda5__gasync_ready_callback, block2_data_ref (_data2_));
#line 182 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	_g_object_unref0 (_tmp3_);
#line 188 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	g_main_loop_run (_data2_->main_loop);
#line 177 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	block2_data_unref (_data2_);
#line 177 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	_data2_ = NULL;
#line 1587 "object-cache.c"
}


static Block3Data* block3_data_ref (Block3Data* _data3_) {
#line 191 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	g_atomic_int_inc (&_data3_->_ref_count_);
#line 191 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	return _data3_;
#line 1596 "object-cache.c"
}


static void block3_data_unref (void * _userdata_) {
	Block3Data* _data3_;
	_data3_ = (Block3Data*) _userdata_;
#line 191 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	if (g_atomic_int_dec_and_test (&_data3_->_ref_count_)) {
#line 1605 "object-cache.c"
		ObjectCacheTests* self;
#line 191 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
		self = _data3_->self;
#line 191 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
		_g_object_unref0 (_data3_->new_obj_set);
#line 191 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
		_g_object_unref0 (_data3_->cache);
#line 191 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
		_g_main_loop_unref0 (_data3_->main_loop);
#line 191 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
		_g_object_unref0 (self);
#line 191 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
		g_slice_free (Block3Data, _data3_);
#line 1619 "object-cache.c"
	}
}


static void __lambda6_ (Block3Data* _data3_, GObject* o, GAsyncResult* r) {
	ObjectCacheTests* self;
	TestCache* _tmp0_ = NULL;
	GAsyncResult* _tmp1_ = NULL;
	GMainLoop* _tmp2_ = NULL;
#line 205 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	self = _data3_->self;
#line 205 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	g_return_if_fail (r != NULL);
#line 207 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	_tmp0_ = _data3_->cache;
#line 207 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	_tmp1_ = r;
#line 207 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	folks_object_cache_store_objects_finish ((FolksObjectCache*) _tmp0_, _tmp1_);
#line 208 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	_tmp2_ = _data3_->main_loop;
#line 208 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	g_main_loop_quit (_tmp2_);
#line 1643 "object-cache.c"
}


static void ___lambda6__gasync_ready_callback (GObject* source_object, GAsyncResult* res, gpointer self) {
#line 205 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	__lambda6_ (self, source_object, res);
#line 205 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	block3_data_unref (self);
#line 1652 "object-cache.c"
}


static void __lambda7_ (Block3Data* _data3_, GObject* o, GAsyncResult* r) {
	ObjectCacheTests* self;
	TestCache* _tmp0_ = NULL;
	GAsyncResult* _tmp1_ = NULL;
	GeeSet* _tmp2_ = NULL;
	GMainLoop* _tmp3_ = NULL;
#line 215 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	self = _data3_->self;
#line 215 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	g_return_if_fail (r != NULL);
#line 217 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	_tmp0_ = _data3_->cache;
#line 217 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	_tmp1_ = r;
#line 217 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	_tmp2_ = folks_object_cache_load_objects_finish ((FolksObjectCache*) _tmp0_, _tmp1_);
#line 217 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	_g_object_unref0 (_data3_->new_obj_set);
#line 217 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	_data3_->new_obj_set = _tmp2_;
#line 218 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	_tmp3_ = _data3_->main_loop;
#line 218 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	g_main_loop_quit (_tmp3_);
#line 1680 "object-cache.c"
}


static void ___lambda7__gasync_ready_callback (GObject* source_object, GAsyncResult* res, gpointer self) {
#line 215 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	__lambda7_ (self, source_object, res);
#line 215 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	block3_data_unref (self);
#line 1689 "object-cache.c"
}


void object_cache_tests_test_load_objects (ObjectCacheTests* self) {
	Block3Data* _data3_;
	GMainLoop* _tmp0_ = NULL;
	TestCache* _tmp1_ = NULL;
	TestObject* obj1 = NULL;
	TestObject* _tmp2_ = NULL;
	TestObject* obj2 = NULL;
	TestObject* _tmp3_ = NULL;
	GeeHashSet* obj_set = NULL;
	GeeHashSet* _tmp4_ = NULL;
	GeeHashSet* _tmp5_ = NULL;
	TestObject* _tmp6_ = NULL;
	GeeHashSet* _tmp7_ = NULL;
	TestObject* _tmp8_ = NULL;
	TestCache* _tmp9_ = NULL;
	GeeHashSet* _tmp10_ = NULL;
	GMainLoop* _tmp11_ = NULL;
	TestCache* _tmp12_ = NULL;
	GMainLoop* _tmp13_ = NULL;
	GeeSet* _tmp14_ = NULL;
	GeeSet* _tmp15_ = NULL;
	gint _tmp16_ = 0;
	gint _tmp17_ = 0;
	GeeHashSet* _tmp18_ = NULL;
	gint _tmp19_ = 0;
	gint _tmp20_ = 0;
	GeeHashSet* _tmp49_ = NULL;
	gint _tmp50_ = 0;
	gint _tmp51_ = 0;
#line 191 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	g_return_if_fail (self != NULL);
#line 191 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	_data3_ = g_slice_new0 (Block3Data);
#line 191 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	_data3_->_ref_count_ = 1;
#line 191 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	_data3_->self = g_object_ref (self);
#line 193 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	_tmp0_ = g_main_loop_new (NULL, FALSE);
#line 193 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	_data3_->main_loop = _tmp0_;
#line 194 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	_tmp1_ = test_cache_new ("test-load-objects");
#line 194 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	_data3_->cache = _tmp1_;
#line 197 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	_tmp2_ = test_object_new ("Foo", (guint) 1);
#line 197 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	obj1 = _tmp2_;
#line 198 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	_tmp3_ = test_object_new ("Bar", (guint) 2);
#line 198 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	obj2 = _tmp3_;
#line 200 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	_tmp4_ = gee_hash_set_new (TYPE_TEST_OBJECT, (GBoxedCopyFunc) test_object_ref, test_object_unref, NULL, NULL, NULL, NULL, NULL, NULL);
#line 200 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	obj_set = _tmp4_;
#line 201 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	_tmp5_ = obj_set;
#line 201 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	_tmp6_ = obj1;
#line 201 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	gee_abstract_collection_add ((GeeAbstractCollection*) _tmp5_, _tmp6_);
#line 202 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	_tmp7_ = obj_set;
#line 202 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	_tmp8_ = obj2;
#line 202 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	gee_abstract_collection_add ((GeeAbstractCollection*) _tmp7_, _tmp8_);
#line 205 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	_tmp9_ = _data3_->cache;
#line 205 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	_tmp10_ = obj_set;
#line 205 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	folks_object_cache_store_objects ((FolksObjectCache*) _tmp9_, (GeeSet*) _tmp10_, NULL, ___lambda6__gasync_ready_callback, block3_data_ref (_data3_));
#line 211 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	_tmp11_ = _data3_->main_loop;
#line 211 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	g_main_loop_run (_tmp11_);
#line 214 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	_data3_->new_obj_set = NULL;
#line 215 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	_tmp12_ = _data3_->cache;
#line 215 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	folks_object_cache_load_objects ((FolksObjectCache*) _tmp12_, NULL, ___lambda7__gasync_ready_callback, block3_data_ref (_data3_));
#line 221 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	_tmp13_ = _data3_->main_loop;
#line 221 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	g_main_loop_run (_tmp13_);
#line 224 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	_tmp14_ = _data3_->new_obj_set;
#line 224 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	_vala_assert (_tmp14_ != NULL, "new_obj_set != null");
#line 225 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	_tmp15_ = _data3_->new_obj_set;
#line 225 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	_tmp16_ = gee_collection_get_size ((GeeCollection*) _tmp15_);
#line 225 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	_tmp17_ = _tmp16_;
#line 225 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	_tmp18_ = obj_set;
#line 225 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	_tmp19_ = gee_abstract_collection_get_size ((GeeCollection*) _tmp18_);
#line 225 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	_tmp20_ = _tmp19_;
#line 225 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	_vala_assert (_tmp17_ == _tmp20_, "new_obj_set.size == obj_set.size");
#line 1800 "object-cache.c"
	{
		GeeIterator* _new_obj_it = NULL;
		GeeSet* _tmp21_ = NULL;
		GeeIterator* _tmp22_ = NULL;
#line 227 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
		_tmp21_ = _data3_->new_obj_set;
#line 227 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
		_tmp22_ = gee_iterable_iterator ((GeeIterable*) _tmp21_);
#line 227 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
		_new_obj_it = _tmp22_;
#line 227 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
		while (TRUE) {
#line 1813 "object-cache.c"
			GeeIterator* _tmp23_ = NULL;
			gboolean _tmp24_ = FALSE;
			TestObject* new_obj = NULL;
			GeeIterator* _tmp25_ = NULL;
			gpointer _tmp26_ = NULL;
			gboolean partner_found = FALSE;
			gboolean _tmp48_ = FALSE;
#line 227 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
			_tmp23_ = _new_obj_it;
#line 227 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
			_tmp24_ = gee_iterator_next (_tmp23_);
#line 227 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
			if (!_tmp24_) {
#line 227 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
				break;
#line 1829 "object-cache.c"
			}
#line 227 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
			_tmp25_ = _new_obj_it;
#line 227 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
			_tmp26_ = gee_iterator_get (_tmp25_);
#line 227 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
			new_obj = (TestObject*) _tmp26_;
#line 229 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
			partner_found = FALSE;
#line 1839 "object-cache.c"
			{
				GeeIterator* _original_obj_it = NULL;
				GeeHashSet* _tmp27_ = NULL;
				GeeIterator* _tmp28_ = NULL;
#line 231 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
				_tmp27_ = obj_set;
#line 231 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
				_tmp28_ = gee_abstract_collection_iterator ((GeeAbstractCollection*) _tmp27_);
#line 231 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
				_original_obj_it = _tmp28_;
#line 231 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
				while (TRUE) {
#line 1852 "object-cache.c"
					GeeIterator* _tmp29_ = NULL;
					gboolean _tmp30_ = FALSE;
					TestObject* original_obj = NULL;
					GeeIterator* _tmp31_ = NULL;
					gpointer _tmp32_ = NULL;
					gboolean _tmp33_ = FALSE;
					TestObject* _tmp34_ = NULL;
					const gchar* _tmp35_ = NULL;
					const gchar* _tmp36_ = NULL;
					TestObject* _tmp37_ = NULL;
					const gchar* _tmp38_ = NULL;
					const gchar* _tmp39_ = NULL;
#line 231 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
					_tmp29_ = _original_obj_it;
#line 231 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
					_tmp30_ = gee_iterator_next (_tmp29_);
#line 231 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
					if (!_tmp30_) {
#line 231 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
						break;
#line 1873 "object-cache.c"
					}
#line 231 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
					_tmp31_ = _original_obj_it;
#line 231 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
					_tmp32_ = gee_iterator_get (_tmp31_);
#line 231 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
					original_obj = (TestObject*) _tmp32_;
#line 233 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
					_tmp34_ = new_obj;
#line 233 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
					_tmp35_ = test_object_get_my_string (_tmp34_);
#line 233 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
					_tmp36_ = _tmp35_;
#line 233 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
					_tmp37_ = original_obj;
#line 233 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
					_tmp38_ = test_object_get_my_string (_tmp37_);
#line 233 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
					_tmp39_ = _tmp38_;
#line 233 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
					if (g_strcmp0 (_tmp36_, _tmp39_) == 0) {
#line 1895 "object-cache.c"
						TestObject* _tmp40_ = NULL;
						guint _tmp41_ = 0U;
						guint _tmp42_ = 0U;
						TestObject* _tmp43_ = NULL;
						guint _tmp44_ = 0U;
						guint _tmp45_ = 0U;
#line 234 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
						_tmp40_ = new_obj;
#line 234 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
						_tmp41_ = test_object_get_my_int (_tmp40_);
#line 234 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
						_tmp42_ = _tmp41_;
#line 234 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
						_tmp43_ = original_obj;
#line 234 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
						_tmp44_ = test_object_get_my_int (_tmp43_);
#line 234 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
						_tmp45_ = _tmp44_;
#line 234 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
						_tmp33_ = _tmp42_ == _tmp45_;
#line 1916 "object-cache.c"
					} else {
#line 233 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
						_tmp33_ = FALSE;
#line 1920 "object-cache.c"
					}
#line 233 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
					if (_tmp33_) {
#line 1924 "object-cache.c"
						GeeHashSet* _tmp46_ = NULL;
						TestObject* _tmp47_ = NULL;
#line 236 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
						_tmp46_ = obj_set;
#line 236 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
						_tmp47_ = original_obj;
#line 236 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
						gee_abstract_collection_remove ((GeeAbstractCollection*) _tmp46_, _tmp47_);
#line 237 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
						partner_found = TRUE;
#line 238 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
						_test_object_unref0 (original_obj);
#line 238 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
						break;
#line 1939 "object-cache.c"
					}
#line 231 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
					_test_object_unref0 (original_obj);
#line 1943 "object-cache.c"
				}
#line 231 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
				_g_object_unref0 (_original_obj_it);
#line 1947 "object-cache.c"
			}
#line 242 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
			_tmp48_ = partner_found;
#line 242 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
			_vala_assert (_tmp48_, "partner_found");
#line 227 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
			_test_object_unref0 (new_obj);
#line 1955 "object-cache.c"
		}
#line 227 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
		_g_object_unref0 (_new_obj_it);
#line 1959 "object-cache.c"
	}
#line 245 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	_tmp49_ = obj_set;
#line 245 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	_tmp50_ = gee_abstract_collection_get_size ((GeeCollection*) _tmp49_);
#line 245 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	_tmp51_ = _tmp50_;
#line 245 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	_vala_assert (_tmp51_ == 0, "obj_set.size == 0");
#line 191 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	_g_object_unref0 (obj_set);
#line 191 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	_test_object_unref0 (obj2);
#line 191 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	_test_object_unref0 (obj1);
#line 191 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	block3_data_unref (_data3_);
#line 191 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	_data3_ = NULL;
#line 1979 "object-cache.c"
}


static Block4Data* block4_data_ref (Block4Data* _data4_) {
#line 248 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	g_atomic_int_inc (&_data4_->_ref_count_);
#line 248 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	return _data4_;
#line 1988 "object-cache.c"
}


static void block4_data_unref (void * _userdata_) {
	Block4Data* _data4_;
	_data4_ = (Block4Data*) _userdata_;
#line 248 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	if (g_atomic_int_dec_and_test (&_data4_->_ref_count_)) {
#line 1997 "object-cache.c"
		ObjectCacheTests* self;
#line 248 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
		self = _data4_->self;
#line 248 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
		_g_object_unref0 (_data4_->new_obj_set);
#line 248 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
		_g_object_unref0 (_data4_->cache);
#line 248 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
		_g_main_loop_unref0 (_data4_->main_loop);
#line 248 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
		_g_object_unref0 (self);
#line 248 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
		g_slice_free (Block4Data, _data4_);
#line 2011 "object-cache.c"
	}
}


static void __lambda8_ (Block4Data* _data4_, GObject* o, GAsyncResult* r) {
	ObjectCacheTests* self;
	GAsyncResult* _tmp0_ = NULL;
#line 254 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	self = _data4_->self;
#line 254 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	g_return_if_fail (r != NULL);
#line 256 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	_tmp0_ = r;
#line 256 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	folks_object_cache_store_objects_finish ((FolksObjectCache*) _data4_->cache, _tmp0_);
#line 257 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	g_main_loop_quit (_data4_->main_loop);
#line 2029 "object-cache.c"
}


static void ___lambda8__gasync_ready_callback (GObject* source_object, GAsyncResult* res, gpointer self) {
#line 254 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	__lambda8_ (self, source_object, res);
#line 254 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	block4_data_unref (self);
#line 2038 "object-cache.c"
}


static void __lambda9_ (Block4Data* _data4_, GObject* o, GAsyncResult* r) {
	ObjectCacheTests* self;
	GAsyncResult* _tmp0_ = NULL;
	GeeSet* _tmp1_ = NULL;
#line 264 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	self = _data4_->self;
#line 264 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	g_return_if_fail (r != NULL);
#line 266 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	_tmp0_ = r;
#line 266 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	_tmp1_ = folks_object_cache_load_objects_finish ((FolksObjectCache*) _data4_->cache, _tmp0_);
#line 266 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	_g_object_unref0 (_data4_->new_obj_set);
#line 266 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	_data4_->new_obj_set = _tmp1_;
#line 267 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	g_main_loop_quit (_data4_->main_loop);
#line 2060 "object-cache.c"
}


static void ___lambda9__gasync_ready_callback (GObject* source_object, GAsyncResult* res, gpointer self) {
#line 264 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	__lambda9_ (self, source_object, res);
#line 264 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	block4_data_unref (self);
#line 2069 "object-cache.c"
}


void object_cache_tests_test_load_objects_empty (ObjectCacheTests* self) {
	Block4Data* _data4_;
	GMainLoop* _tmp0_ = NULL;
	TestCache* _tmp1_ = NULL;
	GeeHashSet* _tmp2_ = NULL;
	GeeHashSet* _tmp3_ = NULL;
	gint _tmp4_ = 0;
	gint _tmp5_ = 0;
#line 248 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	g_return_if_fail (self != NULL);
#line 248 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	_data4_ = g_slice_new0 (Block4Data);
#line 248 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	_data4_->_ref_count_ = 1;
#line 248 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	_data4_->self = g_object_ref (self);
#line 250 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	_tmp0_ = g_main_loop_new (NULL, FALSE);
#line 250 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	_data4_->main_loop = _tmp0_;
#line 251 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	_tmp1_ = test_cache_new ("test-load-objects-empty");
#line 251 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	_data4_->cache = _tmp1_;
#line 254 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	_tmp2_ = gee_hash_set_new (TYPE_TEST_OBJECT, (GBoxedCopyFunc) test_object_ref, test_object_unref, NULL, NULL, NULL, NULL, NULL, NULL);
#line 254 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	_tmp3_ = _tmp2_;
#line 254 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	folks_object_cache_store_objects ((FolksObjectCache*) _data4_->cache, (GeeSet*) _tmp3_, NULL, ___lambda8__gasync_ready_callback, block4_data_ref (_data4_));
#line 254 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	_g_object_unref0 (_tmp3_);
#line 260 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	g_main_loop_run (_data4_->main_loop);
#line 263 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	_data4_->new_obj_set = NULL;
#line 264 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	folks_object_cache_load_objects ((FolksObjectCache*) _data4_->cache, NULL, ___lambda9__gasync_ready_callback, block4_data_ref (_data4_));
#line 270 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	g_main_loop_run (_data4_->main_loop);
#line 273 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	_vala_assert (_data4_->new_obj_set != NULL, "new_obj_set != null");
#line 274 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	_tmp4_ = gee_collection_get_size ((GeeCollection*) _data4_->new_obj_set);
#line 274 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	_tmp5_ = _tmp4_;
#line 274 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	_vala_assert (_tmp5_ == 0, "new_obj_set.size == 0");
#line 248 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	block4_data_unref (_data4_);
#line 248 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	_data4_ = NULL;
#line 2125 "object-cache.c"
}


static Block5Data* block5_data_ref (Block5Data* _data5_) {
#line 277 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	g_atomic_int_inc (&_data5_->_ref_count_);
#line 277 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	return _data5_;
#line 2134 "object-cache.c"
}


static void block5_data_unref (void * _userdata_) {
	Block5Data* _data5_;
	_data5_ = (Block5Data*) _userdata_;
#line 277 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	if (g_atomic_int_dec_and_test (&_data5_->_ref_count_)) {
#line 2143 "object-cache.c"
		ObjectCacheTests* self;
#line 277 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
		self = _data5_->self;
#line 277 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
		_g_object_unref0 (_data5_->new_obj_set);
#line 277 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
		_g_object_unref0 (_data5_->cache);
#line 277 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
		_g_main_loop_unref0 (_data5_->main_loop);
#line 277 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
		_g_object_unref0 (self);
#line 277 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
		g_slice_free (Block5Data, _data5_);
#line 2157 "object-cache.c"
	}
}


static void __lambda10_ (Block5Data* _data5_, GObject* o, GAsyncResult* r) {
	ObjectCacheTests* self;
	GAsyncResult* _tmp0_ = NULL;
	GeeSet* _tmp1_ = NULL;
#line 287 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	self = _data5_->self;
#line 287 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	g_return_if_fail (r != NULL);
#line 289 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	_tmp0_ = r;
#line 289 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	_tmp1_ = folks_object_cache_load_objects_finish ((FolksObjectCache*) _data5_->cache, _tmp0_);
#line 289 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	_g_object_unref0 (_data5_->new_obj_set);
#line 289 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	_data5_->new_obj_set = _tmp1_;
#line 290 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	g_main_loop_quit (_data5_->main_loop);
#line 2180 "object-cache.c"
}


static void ___lambda10__gasync_ready_callback (GObject* source_object, GAsyncResult* res, gpointer self) {
#line 287 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	__lambda10_ (self, source_object, res);
#line 287 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	block5_data_unref (self);
#line 2189 "object-cache.c"
}


void object_cache_tests_test_load_objects_nonexistent (ObjectCacheTests* self) {
	Block5Data* _data5_;
	GMainLoop* _tmp0_ = NULL;
	TestCache* _tmp1_ = NULL;
#line 277 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	g_return_if_fail (self != NULL);
#line 277 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	_data5_ = g_slice_new0 (Block5Data);
#line 277 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	_data5_->_ref_count_ = 1;
#line 277 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	_data5_->self = g_object_ref (self);
#line 279 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	_tmp0_ = g_main_loop_new (NULL, FALSE);
#line 279 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	_data5_->main_loop = _tmp0_;
#line 280 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	_tmp1_ = test_cache_new ("test-load-objects-nonexistent");
#line 280 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	_data5_->cache = _tmp1_;
#line 283 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	_object_cache_tests_delete_cache_directory (self);
#line 286 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	_data5_->new_obj_set = NULL;
#line 287 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	folks_object_cache_load_objects ((FolksObjectCache*) _data5_->cache, NULL, ___lambda10__gasync_ready_callback, block5_data_ref (_data5_));
#line 293 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	g_main_loop_run (_data5_->main_loop);
#line 296 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	_vala_assert (_data5_->new_obj_set == NULL, "new_obj_set == null");
#line 277 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	block5_data_unref (_data5_);
#line 277 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	_data5_ = NULL;
#line 2227 "object-cache.c"
}


static Block6Data* block6_data_ref (Block6Data* _data6_) {
#line 299 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	g_atomic_int_inc (&_data6_->_ref_count_);
#line 299 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	return _data6_;
#line 2236 "object-cache.c"
}


static void block6_data_unref (void * _userdata_) {
	Block6Data* _data6_;
	_data6_ = (Block6Data*) _userdata_;
#line 299 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	if (g_atomic_int_dec_and_test (&_data6_->_ref_count_)) {
#line 2245 "object-cache.c"
		ObjectCacheTests* self;
#line 299 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
		self = _data6_->self;
#line 299 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
		_g_object_unref0 (_data6_->new_obj_set);
#line 299 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
		_g_object_unref0 (_data6_->cache);
#line 299 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
		_g_main_loop_unref0 (_data6_->main_loop);
#line 299 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
		_g_object_unref0 (self);
#line 299 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
		g_slice_free (Block6Data, _data6_);
#line 2259 "object-cache.c"
	}
}


static void __lambda11_ (Block6Data* _data6_, GObject* o, GAsyncResult* r) {
	ObjectCacheTests* self;
	GAsyncResult* _tmp0_ = NULL;
#line 313 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	self = _data6_->self;
#line 313 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	g_return_if_fail (r != NULL);
#line 315 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	_tmp0_ = r;
#line 315 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	folks_object_cache_store_objects_finish ((FolksObjectCache*) _data6_->cache, _tmp0_);
#line 316 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	g_main_loop_quit (_data6_->main_loop);
#line 2277 "object-cache.c"
}


static void ___lambda11__gasync_ready_callback (GObject* source_object, GAsyncResult* res, gpointer self) {
#line 313 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	__lambda11_ (self, source_object, res);
#line 313 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	block6_data_unref (self);
#line 2286 "object-cache.c"
}


static void __lambda12_ (Block6Data* _data6_, GObject* o, GAsyncResult* r) {
	ObjectCacheTests* self;
	GAsyncResult* _tmp0_ = NULL;
#line 322 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	self = _data6_->self;
#line 322 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	g_return_if_fail (r != NULL);
#line 324 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	_tmp0_ = r;
#line 324 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	folks_object_cache_clear_cache_finish ((FolksObjectCache*) _data6_->cache, _tmp0_);
#line 325 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	g_main_loop_quit (_data6_->main_loop);
#line 2303 "object-cache.c"
}


static void ___lambda12__gasync_ready_callback (GObject* source_object, GAsyncResult* res, gpointer self) {
#line 322 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	__lambda12_ (self, source_object, res);
#line 322 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	block6_data_unref (self);
#line 2312 "object-cache.c"
}


static void __lambda13_ (Block6Data* _data6_, GObject* o, GAsyncResult* r) {
	ObjectCacheTests* self;
	GAsyncResult* _tmp0_ = NULL;
	GeeSet* _tmp1_ = NULL;
#line 332 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	self = _data6_->self;
#line 332 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	g_return_if_fail (r != NULL);
#line 334 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	_tmp0_ = r;
#line 334 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	_tmp1_ = folks_object_cache_load_objects_finish ((FolksObjectCache*) _data6_->cache, _tmp0_);
#line 334 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	_g_object_unref0 (_data6_->new_obj_set);
#line 334 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	_data6_->new_obj_set = _tmp1_;
#line 335 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	g_main_loop_quit (_data6_->main_loop);
#line 2334 "object-cache.c"
}


static void ___lambda13__gasync_ready_callback (GObject* source_object, GAsyncResult* res, gpointer self) {
#line 332 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	__lambda13_ (self, source_object, res);
#line 332 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	block6_data_unref (self);
#line 2343 "object-cache.c"
}


void object_cache_tests_test_clear (ObjectCacheTests* self) {
	Block6Data* _data6_;
	GMainLoop* _tmp0_ = NULL;
	TestCache* _tmp1_ = NULL;
	TestObject* obj1 = NULL;
	TestObject* _tmp2_ = NULL;
	TestObject* obj2 = NULL;
	TestObject* _tmp3_ = NULL;
	GeeHashSet* obj_set = NULL;
	GeeHashSet* _tmp4_ = NULL;
#line 299 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	g_return_if_fail (self != NULL);
#line 299 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	_data6_ = g_slice_new0 (Block6Data);
#line 299 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	_data6_->_ref_count_ = 1;
#line 299 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	_data6_->self = g_object_ref (self);
#line 301 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	_tmp0_ = g_main_loop_new (NULL, FALSE);
#line 301 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	_data6_->main_loop = _tmp0_;
#line 302 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	_tmp1_ = test_cache_new ("test-clear");
#line 302 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	_data6_->cache = _tmp1_;
#line 305 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	_tmp2_ = test_object_new ("Foo", (guint) 1);
#line 305 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	obj1 = _tmp2_;
#line 306 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	_tmp3_ = test_object_new ("Bar", (guint) 2);
#line 306 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	obj2 = _tmp3_;
#line 308 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	_tmp4_ = gee_hash_set_new (TYPE_TEST_OBJECT, (GBoxedCopyFunc) test_object_ref, test_object_unref, NULL, NULL, NULL, NULL, NULL, NULL);
#line 308 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	obj_set = _tmp4_;
#line 309 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	gee_abstract_collection_add ((GeeAbstractCollection*) obj_set, obj1);
#line 310 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	gee_abstract_collection_add ((GeeAbstractCollection*) obj_set, obj2);
#line 313 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	folks_object_cache_store_objects ((FolksObjectCache*) _data6_->cache, (GeeSet*) obj_set, NULL, ___lambda11__gasync_ready_callback, block6_data_ref (_data6_));
#line 319 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	g_main_loop_run (_data6_->main_loop);
#line 322 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	folks_object_cache_clear_cache ((FolksObjectCache*) _data6_->cache, ___lambda12__gasync_ready_callback, block6_data_ref (_data6_));
#line 328 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	g_main_loop_run (_data6_->main_loop);
#line 331 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	_data6_->new_obj_set = NULL;
#line 332 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	folks_object_cache_load_objects ((FolksObjectCache*) _data6_->cache, NULL, ___lambda13__gasync_ready_callback, block6_data_ref (_data6_));
#line 338 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	g_main_loop_run (_data6_->main_loop);
#line 340 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	_vala_assert (_data6_->new_obj_set == NULL, "new_obj_set == null");
#line 299 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	_g_object_unref0 (obj_set);
#line 299 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	_test_object_unref0 (obj2);
#line 299 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	_test_object_unref0 (obj1);
#line 299 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	block6_data_unref (_data6_);
#line 299 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	_data6_ = NULL;
#line 2415 "object-cache.c"
}


static Block7Data* block7_data_ref (Block7Data* _data7_) {
#line 343 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	g_atomic_int_inc (&_data7_->_ref_count_);
#line 343 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	return _data7_;
#line 2424 "object-cache.c"
}


static void block7_data_unref (void * _userdata_) {
	Block7Data* _data7_;
	_data7_ = (Block7Data*) _userdata_;
#line 343 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	if (g_atomic_int_dec_and_test (&_data7_->_ref_count_)) {
#line 2433 "object-cache.c"
		ObjectCacheTests* self;
#line 343 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
		self = _data7_->self;
#line 343 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
		_g_object_unref0 (_data7_->new_obj_set);
#line 343 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
		_g_object_unref0 (_data7_->cache);
#line 343 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
		_g_main_loop_unref0 (_data7_->main_loop);
#line 343 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
		_g_object_unref0 (self);
#line 343 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
		g_slice_free (Block7Data, _data7_);
#line 2447 "object-cache.c"
	}
}


static void __lambda14_ (Block7Data* _data7_, GObject* o, GAsyncResult* r) {
	ObjectCacheTests* self;
	GAsyncResult* _tmp0_ = NULL;
#line 349 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	self = _data7_->self;
#line 349 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	g_return_if_fail (r != NULL);
#line 351 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	_tmp0_ = r;
#line 351 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	folks_object_cache_store_objects_finish ((FolksObjectCache*) _data7_->cache, _tmp0_);
#line 352 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	g_main_loop_quit (_data7_->main_loop);
#line 2465 "object-cache.c"
}


static void ___lambda14__gasync_ready_callback (GObject* source_object, GAsyncResult* res, gpointer self) {
#line 349 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	__lambda14_ (self, source_object, res);
#line 349 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	block7_data_unref (self);
#line 2474 "object-cache.c"
}


static void __lambda15_ (Block7Data* _data7_, GObject* o, GAsyncResult* r) {
	ObjectCacheTests* self;
	GAsyncResult* _tmp0_ = NULL;
#line 358 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	self = _data7_->self;
#line 358 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	g_return_if_fail (r != NULL);
#line 360 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	_tmp0_ = r;
#line 360 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	folks_object_cache_clear_cache_finish ((FolksObjectCache*) _data7_->cache, _tmp0_);
#line 361 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	g_main_loop_quit (_data7_->main_loop);
#line 2491 "object-cache.c"
}


static void ___lambda15__gasync_ready_callback (GObject* source_object, GAsyncResult* res, gpointer self) {
#line 358 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	__lambda15_ (self, source_object, res);
#line 358 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	block7_data_unref (self);
#line 2500 "object-cache.c"
}


static void __lambda16_ (Block7Data* _data7_, GObject* o, GAsyncResult* r) {
	ObjectCacheTests* self;
	GAsyncResult* _tmp0_ = NULL;
	GeeSet* _tmp1_ = NULL;
#line 368 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	self = _data7_->self;
#line 368 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	g_return_if_fail (r != NULL);
#line 370 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	_tmp0_ = r;
#line 370 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	_tmp1_ = folks_object_cache_load_objects_finish ((FolksObjectCache*) _data7_->cache, _tmp0_);
#line 370 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	_g_object_unref0 (_data7_->new_obj_set);
#line 370 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	_data7_->new_obj_set = _tmp1_;
#line 371 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	g_main_loop_quit (_data7_->main_loop);
#line 2522 "object-cache.c"
}


static void ___lambda16__gasync_ready_callback (GObject* source_object, GAsyncResult* res, gpointer self) {
#line 368 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	__lambda16_ (self, source_object, res);
#line 368 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	block7_data_unref (self);
#line 2531 "object-cache.c"
}


void object_cache_tests_test_clear_empty (ObjectCacheTests* self) {
	Block7Data* _data7_;
	GMainLoop* _tmp0_ = NULL;
	TestCache* _tmp1_ = NULL;
	GeeHashSet* _tmp2_ = NULL;
	GeeHashSet* _tmp3_ = NULL;
#line 343 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	g_return_if_fail (self != NULL);
#line 343 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	_data7_ = g_slice_new0 (Block7Data);
#line 343 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	_data7_->_ref_count_ = 1;
#line 343 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	_data7_->self = g_object_ref (self);
#line 345 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	_tmp0_ = g_main_loop_new (NULL, FALSE);
#line 345 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	_data7_->main_loop = _tmp0_;
#line 346 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	_tmp1_ = test_cache_new ("test-clear-empty");
#line 346 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	_data7_->cache = _tmp1_;
#line 349 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	_tmp2_ = gee_hash_set_new (TYPE_TEST_OBJECT, (GBoxedCopyFunc) test_object_ref, test_object_unref, NULL, NULL, NULL, NULL, NULL, NULL);
#line 349 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	_tmp3_ = _tmp2_;
#line 349 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	folks_object_cache_store_objects ((FolksObjectCache*) _data7_->cache, (GeeSet*) _tmp3_, NULL, ___lambda14__gasync_ready_callback, block7_data_ref (_data7_));
#line 349 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	_g_object_unref0 (_tmp3_);
#line 355 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	g_main_loop_run (_data7_->main_loop);
#line 358 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	folks_object_cache_clear_cache ((FolksObjectCache*) _data7_->cache, ___lambda15__gasync_ready_callback, block7_data_ref (_data7_));
#line 364 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	g_main_loop_run (_data7_->main_loop);
#line 367 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	_data7_->new_obj_set = NULL;
#line 368 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	folks_object_cache_load_objects ((FolksObjectCache*) _data7_->cache, NULL, ___lambda16__gasync_ready_callback, block7_data_ref (_data7_));
#line 374 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	g_main_loop_run (_data7_->main_loop);
#line 376 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	_vala_assert (_data7_->new_obj_set == NULL, "new_obj_set == null");
#line 343 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	block7_data_unref (_data7_);
#line 343 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	_data7_ = NULL;
#line 2583 "object-cache.c"
}


static Block8Data* block8_data_ref (Block8Data* _data8_) {
#line 379 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	g_atomic_int_inc (&_data8_->_ref_count_);
#line 379 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	return _data8_;
#line 2592 "object-cache.c"
}


static void block8_data_unref (void * _userdata_) {
	Block8Data* _data8_;
	_data8_ = (Block8Data*) _userdata_;
#line 379 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	if (g_atomic_int_dec_and_test (&_data8_->_ref_count_)) {
#line 2601 "object-cache.c"
		ObjectCacheTests* self;
#line 379 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
		self = _data8_->self;
#line 379 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
		_g_object_unref0 (_data8_->new_obj_set);
#line 379 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
		_g_object_unref0 (_data8_->cache);
#line 379 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
		_g_main_loop_unref0 (_data8_->main_loop);
#line 379 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
		_g_object_unref0 (self);
#line 379 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
		g_slice_free (Block8Data, _data8_);
#line 2615 "object-cache.c"
	}
}


static void __lambda17_ (Block8Data* _data8_, GObject* o, GAsyncResult* r) {
	ObjectCacheTests* self;
	GAsyncResult* _tmp0_ = NULL;
#line 388 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	self = _data8_->self;
#line 388 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	g_return_if_fail (r != NULL);
#line 390 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	_tmp0_ = r;
#line 390 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	folks_object_cache_clear_cache_finish ((FolksObjectCache*) _data8_->cache, _tmp0_);
#line 391 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	g_main_loop_quit (_data8_->main_loop);
#line 2633 "object-cache.c"
}


static void ___lambda17__gasync_ready_callback (GObject* source_object, GAsyncResult* res, gpointer self) {
#line 388 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	__lambda17_ (self, source_object, res);
#line 388 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	block8_data_unref (self);
#line 2642 "object-cache.c"
}


static void __lambda18_ (Block8Data* _data8_, GObject* o, GAsyncResult* r) {
	ObjectCacheTests* self;
	GAsyncResult* _tmp0_ = NULL;
	GeeSet* _tmp1_ = NULL;
#line 398 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	self = _data8_->self;
#line 398 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	g_return_if_fail (r != NULL);
#line 400 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	_tmp0_ = r;
#line 400 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	_tmp1_ = folks_object_cache_load_objects_finish ((FolksObjectCache*) _data8_->cache, _tmp0_);
#line 400 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	_g_object_unref0 (_data8_->new_obj_set);
#line 400 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	_data8_->new_obj_set = _tmp1_;
#line 401 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	g_main_loop_quit (_data8_->main_loop);
#line 2664 "object-cache.c"
}


static void ___lambda18__gasync_ready_callback (GObject* source_object, GAsyncResult* res, gpointer self) {
#line 398 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	__lambda18_ (self, source_object, res);
#line 398 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	block8_data_unref (self);
#line 2673 "object-cache.c"
}


void object_cache_tests_test_clear_nonexistent (ObjectCacheTests* self) {
	Block8Data* _data8_;
	GMainLoop* _tmp0_ = NULL;
	TestCache* _tmp1_ = NULL;
#line 379 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	g_return_if_fail (self != NULL);
#line 379 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	_data8_ = g_slice_new0 (Block8Data);
#line 379 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	_data8_->_ref_count_ = 1;
#line 379 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	_data8_->self = g_object_ref (self);
#line 381 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	_tmp0_ = g_main_loop_new (NULL, FALSE);
#line 381 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	_data8_->main_loop = _tmp0_;
#line 382 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	_tmp1_ = test_cache_new ("test-clear-nonexistent");
#line 382 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	_data8_->cache = _tmp1_;
#line 385 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	_object_cache_tests_delete_cache_directory (self);
#line 388 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	folks_object_cache_clear_cache ((FolksObjectCache*) _data8_->cache, ___lambda17__gasync_ready_callback, block8_data_ref (_data8_));
#line 394 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	g_main_loop_run (_data8_->main_loop);
#line 397 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	_data8_->new_obj_set = NULL;
#line 398 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	folks_object_cache_load_objects ((FolksObjectCache*) _data8_->cache, NULL, ___lambda18__gasync_ready_callback, block8_data_ref (_data8_));
#line 404 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	g_main_loop_run (_data8_->main_loop);
#line 406 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	_vala_assert (_data8_->new_obj_set == NULL, "new_obj_set == null");
#line 379 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	block8_data_unref (_data8_);
#line 379 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	_data8_ = NULL;
#line 2715 "object-cache.c"
}


static Block9Data* block9_data_ref (Block9Data* _data9_) {
#line 409 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	g_atomic_int_inc (&_data9_->_ref_count_);
#line 409 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	return _data9_;
#line 2724 "object-cache.c"
}


static void block9_data_unref (void * _userdata_) {
	Block9Data* _data9_;
	_data9_ = (Block9Data*) _userdata_;
#line 409 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	if (g_atomic_int_dec_and_test (&_data9_->_ref_count_)) {
#line 2733 "object-cache.c"
		ObjectCacheTests* self;
#line 409 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
		self = _data9_->self;
#line 409 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
		_g_object_unref0 (_data9_->new_obj_set);
#line 409 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
		_g_object_unref0 (_data9_->cache);
#line 409 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
		_g_main_loop_unref0 (_data9_->main_loop);
#line 409 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
		_g_object_unref0 (self);
#line 409 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
		g_slice_free (Block9Data, _data9_);
#line 2747 "object-cache.c"
	}
}


static void __lambda19_ (Block9Data* _data9_, GObject* o, GAsyncResult* r) {
	ObjectCacheTests* self;
	GAsyncResult* _tmp0_ = NULL;
#line 422 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	self = _data9_->self;
#line 422 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	g_return_if_fail (r != NULL);
#line 424 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	_tmp0_ = r;
#line 424 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	folks_object_cache_store_objects_finish ((FolksObjectCache*) _data9_->cache, _tmp0_);
#line 425 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	g_main_loop_quit (_data9_->main_loop);
#line 2765 "object-cache.c"
}


static void ___lambda19__gasync_ready_callback (GObject* source_object, GAsyncResult* res, gpointer self) {
#line 422 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	__lambda19_ (self, source_object, res);
#line 422 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	block9_data_unref (self);
#line 2774 "object-cache.c"
}


static void __lambda20_ (Block9Data* _data9_, GObject* o, GAsyncResult* r) {
	ObjectCacheTests* self;
	GAsyncResult* _tmp0_ = NULL;
	GeeSet* _tmp1_ = NULL;
#line 434 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	self = _data9_->self;
#line 434 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	g_return_if_fail (r != NULL);
#line 436 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	_tmp0_ = r;
#line 436 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	_tmp1_ = folks_object_cache_load_objects_finish ((FolksObjectCache*) _data9_->cache, _tmp0_);
#line 436 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	_g_object_unref0 (_data9_->new_obj_set);
#line 436 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	_data9_->new_obj_set = _tmp1_;
#line 437 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	g_main_loop_quit (_data9_->main_loop);
#line 2796 "object-cache.c"
}


static void ___lambda20__gasync_ready_callback (GObject* source_object, GAsyncResult* res, gpointer self) {
#line 434 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	__lambda20_ (self, source_object, res);
#line 434 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	block9_data_unref (self);
#line 2805 "object-cache.c"
}


void object_cache_tests_test_store_objects_cancellation (ObjectCacheTests* self) {
	Block9Data* _data9_;
	GMainLoop* _tmp0_ = NULL;
	TestCache* _tmp1_ = NULL;
	GeeHashSet* obj_set = NULL;
	GeeHashSet* _tmp2_ = NULL;
	TestObject* _tmp3_ = NULL;
	TestObject* _tmp4_ = NULL;
	TestObject* _tmp5_ = NULL;
	TestObject* _tmp6_ = NULL;
	TestObject* _tmp7_ = NULL;
	TestObject* _tmp8_ = NULL;
	TestObject* _tmp9_ = NULL;
	TestObject* _tmp10_ = NULL;
	GCancellable* cancellable = NULL;
	GCancellable* _tmp11_ = NULL;
#line 409 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	g_return_if_fail (self != NULL);
#line 409 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	_data9_ = g_slice_new0 (Block9Data);
#line 409 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	_data9_->_ref_count_ = 1;
#line 409 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	_data9_->self = g_object_ref (self);
#line 411 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	_tmp0_ = g_main_loop_new (NULL, FALSE);
#line 411 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	_data9_->main_loop = _tmp0_;
#line 412 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	_tmp1_ = test_cache_new ("test-store-objects-cancellation");
#line 412 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	_data9_->cache = _tmp1_;
#line 414 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	_tmp2_ = gee_hash_set_new (TYPE_TEST_OBJECT, (GBoxedCopyFunc) test_object_ref, test_object_unref, NULL, NULL, NULL, NULL, NULL, NULL);
#line 414 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	obj_set = _tmp2_;
#line 415 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	_tmp3_ = test_object_new ("Foo", (guint) 1);
#line 415 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	_tmp4_ = _tmp3_;
#line 415 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	gee_abstract_collection_add ((GeeAbstractCollection*) obj_set, _tmp4_);
#line 415 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	_test_object_unref0 (_tmp4_);
#line 416 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	_tmp5_ = test_object_new ("Bar", (guint) 2);
#line 416 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	_tmp6_ = _tmp5_;
#line 416 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	gee_abstract_collection_add ((GeeAbstractCollection*) obj_set, _tmp6_);
#line 416 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	_test_object_unref0 (_tmp6_);
#line 417 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	_tmp7_ = test_object_new ("De", (guint) 3);
#line 417 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	_tmp8_ = _tmp7_;
#line 417 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	gee_abstract_collection_add ((GeeAbstractCollection*) obj_set, _tmp8_);
#line 417 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	_test_object_unref0 (_tmp8_);
#line 418 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	_tmp9_ = test_object_new ("Baz", (guint) 4);
#line 418 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	_tmp10_ = _tmp9_;
#line 418 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	gee_abstract_collection_add ((GeeAbstractCollection*) obj_set, _tmp10_);
#line 418 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	_test_object_unref0 (_tmp10_);
#line 420 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	_tmp11_ = g_cancellable_new ();
#line 420 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	cancellable = _tmp11_;
#line 422 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	folks_object_cache_store_objects ((FolksObjectCache*) _data9_->cache, (GeeSet*) obj_set, cancellable, ___lambda19__gasync_ready_callback, block9_data_ref (_data9_));
#line 429 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	g_cancellable_cancel (cancellable);
#line 430 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	g_main_loop_run (_data9_->main_loop);
#line 433 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	_data9_->new_obj_set = NULL;
#line 434 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	folks_object_cache_load_objects ((FolksObjectCache*) _data9_->cache, NULL, ___lambda20__gasync_ready_callback, block9_data_ref (_data9_));
#line 440 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	g_main_loop_run (_data9_->main_loop);
#line 442 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	_vala_assert (_data9_->new_obj_set == NULL, "new_obj_set == null");
#line 409 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	_g_object_unref0 (cancellable);
#line 409 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	_g_object_unref0 (obj_set);
#line 409 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	block9_data_unref (_data9_);
#line 409 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	_data9_ = NULL;
#line 2903 "object-cache.c"
}


static Block10Data* block10_data_ref (Block10Data* _data10_) {
#line 445 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	g_atomic_int_inc (&_data10_->_ref_count_);
#line 445 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	return _data10_;
#line 2912 "object-cache.c"
}


static void block10_data_unref (void * _userdata_) {
	Block10Data* _data10_;
	_data10_ = (Block10Data*) _userdata_;
#line 445 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	if (g_atomic_int_dec_and_test (&_data10_->_ref_count_)) {
#line 2921 "object-cache.c"
		ObjectCacheTests* self;
#line 445 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
		self = _data10_->self;
#line 445 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
		_g_object_unref0 (_data10_->new_obj_set);
#line 445 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
		_g_object_unref0 (_data10_->cache);
#line 445 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
		_g_main_loop_unref0 (_data10_->main_loop);
#line 445 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
		_g_object_unref0 (self);
#line 445 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
		g_slice_free (Block10Data, _data10_);
#line 2935 "object-cache.c"
	}
}


static void __lambda21_ (Block10Data* _data10_, GObject* o, GAsyncResult* r) {
	ObjectCacheTests* self;
	GAsyncResult* _tmp0_ = NULL;
#line 459 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	self = _data10_->self;
#line 459 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	g_return_if_fail (r != NULL);
#line 461 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	_tmp0_ = r;
#line 461 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	folks_object_cache_store_objects_finish ((FolksObjectCache*) _data10_->cache, _tmp0_);
#line 462 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	g_main_loop_quit (_data10_->main_loop);
#line 2953 "object-cache.c"
}


static void ___lambda21__gasync_ready_callback (GObject* source_object, GAsyncResult* res, gpointer self) {
#line 459 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	__lambda21_ (self, source_object, res);
#line 459 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	block10_data_unref (self);
#line 2962 "object-cache.c"
}


static void __lambda22_ (Block10Data* _data10_, GObject* o, GAsyncResult* r) {
	ObjectCacheTests* self;
	GAsyncResult* _tmp0_ = NULL;
	GeeSet* _tmp1_ = NULL;
#line 471 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	self = _data10_->self;
#line 471 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	g_return_if_fail (r != NULL);
#line 473 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	_tmp0_ = r;
#line 473 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	_tmp1_ = folks_object_cache_load_objects_finish ((FolksObjectCache*) _data10_->cache, _tmp0_);
#line 473 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	_g_object_unref0 (_data10_->new_obj_set);
#line 473 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	_data10_->new_obj_set = _tmp1_;
#line 474 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	g_main_loop_quit (_data10_->main_loop);
#line 2984 "object-cache.c"
}


static void ___lambda22__gasync_ready_callback (GObject* source_object, GAsyncResult* res, gpointer self) {
#line 471 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	__lambda22_ (self, source_object, res);
#line 471 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	block10_data_unref (self);
#line 2993 "object-cache.c"
}


void object_cache_tests_test_load_objects_cancellation (ObjectCacheTests* self) {
	Block10Data* _data10_;
	GMainLoop* _tmp0_ = NULL;
	TestCache* _tmp1_ = NULL;
	TestObject* obj1 = NULL;
	TestObject* _tmp2_ = NULL;
	TestObject* obj2 = NULL;
	TestObject* _tmp3_ = NULL;
	GeeHashSet* obj_set = NULL;
	GeeHashSet* _tmp4_ = NULL;
	GCancellable* cancellable = NULL;
	GCancellable* _tmp5_ = NULL;
#line 445 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	g_return_if_fail (self != NULL);
#line 445 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	_data10_ = g_slice_new0 (Block10Data);
#line 445 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	_data10_->_ref_count_ = 1;
#line 445 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	_data10_->self = g_object_ref (self);
#line 447 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	_tmp0_ = g_main_loop_new (NULL, FALSE);
#line 447 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	_data10_->main_loop = _tmp0_;
#line 448 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	_tmp1_ = test_cache_new ("test-load-objects-cancellation");
#line 448 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	_data10_->cache = _tmp1_;
#line 451 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	_tmp2_ = test_object_new ("Foo", (guint) 1);
#line 451 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	obj1 = _tmp2_;
#line 452 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	_tmp3_ = test_object_new ("Bar", (guint) 2);
#line 452 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	obj2 = _tmp3_;
#line 454 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	_tmp4_ = gee_hash_set_new (TYPE_TEST_OBJECT, (GBoxedCopyFunc) test_object_ref, test_object_unref, NULL, NULL, NULL, NULL, NULL, NULL);
#line 454 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	obj_set = _tmp4_;
#line 455 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	gee_abstract_collection_add ((GeeAbstractCollection*) obj_set, obj1);
#line 456 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	gee_abstract_collection_add ((GeeAbstractCollection*) obj_set, obj2);
#line 459 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	folks_object_cache_store_objects ((FolksObjectCache*) _data10_->cache, (GeeSet*) obj_set, NULL, ___lambda21__gasync_ready_callback, block10_data_ref (_data10_));
#line 465 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	g_main_loop_run (_data10_->main_loop);
#line 468 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	_tmp5_ = g_cancellable_new ();
#line 468 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	cancellable = _tmp5_;
#line 470 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	_data10_->new_obj_set = NULL;
#line 471 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	folks_object_cache_load_objects ((FolksObjectCache*) _data10_->cache, cancellable, ___lambda22__gasync_ready_callback, block10_data_ref (_data10_));
#line 478 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	g_cancellable_cancel (cancellable);
#line 479 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	g_main_loop_run (_data10_->main_loop);
#line 481 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	_vala_assert (_data10_->new_obj_set == NULL, "new_obj_set == null");
#line 445 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	_g_object_unref0 (cancellable);
#line 445 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	_g_object_unref0 (obj_set);
#line 445 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	_test_object_unref0 (obj2);
#line 445 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	_test_object_unref0 (obj1);
#line 445 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	block10_data_unref (_data10_);
#line 445 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	_data10_ = NULL;
#line 3071 "object-cache.c"
}


static Block11Data* block11_data_ref (Block11Data* _data11_) {
#line 484 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	g_atomic_int_inc (&_data11_->_ref_count_);
#line 484 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	return _data11_;
#line 3080 "object-cache.c"
}


static void block11_data_unref (void * _userdata_) {
	Block11Data* _data11_;
	_data11_ = (Block11Data*) _userdata_;
#line 484 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	if (g_atomic_int_dec_and_test (&_data11_->_ref_count_)) {
#line 3089 "object-cache.c"
		ObjectCacheTests* self;
#line 484 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
		self = _data11_->self;
#line 484 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
		_g_object_unref0 (_data11_->new_obj_set);
#line 484 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
		_g_object_unref0 (_data11_->cache);
#line 484 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
		_g_main_loop_unref0 (_data11_->main_loop);
#line 484 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
		_g_object_unref0 (self);
#line 484 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
		g_slice_free (Block11Data, _data11_);
#line 3103 "object-cache.c"
	}
}


static void __lambda23_ (Block11Data* _data11_, GObject* o, GAsyncResult* r) {
	ObjectCacheTests* self;
	gdouble elapsed_time = 0.0;
	gdouble _tmp0_ = 0.0;
	gint _tmp1_ = 0;
	TestCache* _tmp2_ = NULL;
	GAsyncResult* _tmp3_ = NULL;
	GMainLoop* _tmp4_ = NULL;
#line 501 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	self = _data11_->self;
#line 501 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	g_return_if_fail (r != NULL);
#line 503 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	_tmp0_ = g_test_timer_elapsed ();
#line 503 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	elapsed_time = _tmp0_;
#line 504 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	_tmp1_ = _data11_->obj_count;
#line 504 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	g_message ("object-cache.vala:504: Storing %u objects in a cache file took %f seco" \
"nds.", (guint) _tmp1_, elapsed_time);
#line 507 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	_tmp2_ = _data11_->cache;
#line 507 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	_tmp3_ = r;
#line 507 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	folks_object_cache_store_objects_finish ((FolksObjectCache*) _tmp2_, _tmp3_);
#line 508 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	_tmp4_ = _data11_->main_loop;
#line 508 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	g_main_loop_quit (_tmp4_);
#line 3138 "object-cache.c"
}


static void ___lambda23__gasync_ready_callback (GObject* source_object, GAsyncResult* res, gpointer self) {
#line 501 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	__lambda23_ (self, source_object, res);
#line 501 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	block11_data_unref (self);
#line 3147 "object-cache.c"
}


static void __lambda24_ (Block11Data* _data11_, GObject* o, GAsyncResult* r) {
	ObjectCacheTests* self;
	gdouble elapsed_time = 0.0;
	gdouble _tmp0_ = 0.0;
	gint _tmp1_ = 0;
	TestCache* _tmp2_ = NULL;
	GAsyncResult* _tmp3_ = NULL;
	GeeSet* _tmp4_ = NULL;
	GMainLoop* _tmp5_ = NULL;
#line 517 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	self = _data11_->self;
#line 517 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	g_return_if_fail (r != NULL);
#line 519 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	_tmp0_ = g_test_timer_elapsed ();
#line 519 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	elapsed_time = _tmp0_;
#line 520 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	_tmp1_ = _data11_->obj_count;
#line 520 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	g_message ("object-cache.vala:520: Loading %u objects from a cache file took %f se" \
"conds.", (guint) _tmp1_, elapsed_time);
#line 523 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	_tmp2_ = _data11_->cache;
#line 523 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	_tmp3_ = r;
#line 523 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	_tmp4_ = folks_object_cache_load_objects_finish ((FolksObjectCache*) _tmp2_, _tmp3_);
#line 523 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	_g_object_unref0 (_data11_->new_obj_set);
#line 523 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	_data11_->new_obj_set = _tmp4_;
#line 524 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	_tmp5_ = _data11_->main_loop;
#line 524 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	g_main_loop_quit (_tmp5_);
#line 3186 "object-cache.c"
}


static void ___lambda24__gasync_ready_callback (GObject* source_object, GAsyncResult* res, gpointer self) {
#line 517 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	__lambda24_ (self, source_object, res);
#line 517 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	block11_data_unref (self);
#line 3195 "object-cache.c"
}


void object_cache_tests_test_stress (ObjectCacheTests* self) {
	Block11Data* _data11_;
	GMainLoop* _tmp0_ = NULL;
	TestCache* _tmp1_ = NULL;
	GeeHashSet* obj_set = NULL;
	GeeHashSet* _tmp2_ = NULL;
	TestCache* _tmp11_ = NULL;
	GeeHashSet* _tmp12_ = NULL;
	GMainLoop* _tmp13_ = NULL;
	TestCache* _tmp14_ = NULL;
	GMainLoop* _tmp15_ = NULL;
	gint _tmp16_ = 0;
	gint _tmp17_ = 0;
	GeeHashSet* _tmp18_ = NULL;
	gint _tmp19_ = 0;
	gint _tmp20_ = 0;
#line 484 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	g_return_if_fail (self != NULL);
#line 484 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	_data11_ = g_slice_new0 (Block11Data);
#line 484 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	_data11_->_ref_count_ = 1;
#line 484 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	_data11_->self = g_object_ref (self);
#line 486 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	_tmp0_ = g_main_loop_new (NULL, FALSE);
#line 486 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	_data11_->main_loop = _tmp0_;
#line 487 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	_tmp1_ = test_cache_new ("test-stress");
#line 487 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	_data11_->cache = _tmp1_;
#line 490 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	_data11_->obj_count = 66666;
#line 491 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	_tmp2_ = gee_hash_set_new (TYPE_TEST_OBJECT, (GBoxedCopyFunc) test_object_ref, test_object_unref, NULL, NULL, NULL, NULL, NULL, NULL);
#line 491 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	obj_set = _tmp2_;
#line 3237 "object-cache.c"
	{
		gint i = 0;
#line 493 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
		i = 0;
#line 3242 "object-cache.c"
		{
			gboolean _tmp3_ = FALSE;
#line 493 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
			_tmp3_ = TRUE;
#line 493 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
			while (TRUE) {
#line 3249 "object-cache.c"
				gint _tmp5_ = 0;
				gint _tmp6_ = 0;
				GeeHashSet* _tmp7_ = NULL;
				gint _tmp8_ = 0;
				TestObject* _tmp9_ = NULL;
				TestObject* _tmp10_ = NULL;
#line 493 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
				if (!_tmp3_) {
#line 3258 "object-cache.c"
					gint _tmp4_ = 0;
#line 493 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
					_tmp4_ = i;
#line 493 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
					i = _tmp4_ + 1;
#line 3264 "object-cache.c"
				}
#line 493 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
				_tmp3_ = FALSE;
#line 493 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
				_tmp5_ = i;
#line 493 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
				_tmp6_ = _data11_->obj_count;
#line 493 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
				if (!(_tmp5_ < _tmp6_)) {
#line 493 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
					break;
#line 3276 "object-cache.c"
				}
#line 495 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
				_tmp7_ = obj_set;
#line 495 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
				_tmp8_ = i;
#line 495 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
				_tmp9_ = test_object_new ("bizzle", (guint) _tmp8_);
#line 495 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
				_tmp10_ = _tmp9_;
#line 495 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
				gee_abstract_collection_add ((GeeAbstractCollection*) _tmp7_, _tmp10_);
#line 495 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
				_test_object_unref0 (_tmp10_);
#line 3290 "object-cache.c"
			}
		}
	}
#line 499 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	g_test_timer_start ();
#line 501 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	_tmp11_ = _data11_->cache;
#line 501 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	_tmp12_ = obj_set;
#line 501 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	folks_object_cache_store_objects ((FolksObjectCache*) _tmp11_, (GeeSet*) _tmp12_, NULL, ___lambda23__gasync_ready_callback, block11_data_ref (_data11_));
#line 511 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	_tmp13_ = _data11_->main_loop;
#line 511 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	g_main_loop_run (_tmp13_);
#line 514 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	g_test_timer_start ();
#line 516 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	_data11_->new_obj_set = NULL;
#line 517 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	_tmp14_ = _data11_->cache;
#line 517 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	folks_object_cache_load_objects ((FolksObjectCache*) _tmp14_, NULL, ___lambda24__gasync_ready_callback, block11_data_ref (_data11_));
#line 527 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	_tmp15_ = _data11_->main_loop;
#line 527 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	g_main_loop_run (_tmp15_);
#line 531 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	_vala_assert (_data11_->new_obj_set != NULL, "new_obj_set != null");
#line 532 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	_tmp16_ = gee_collection_get_size ((GeeCollection*) _data11_->new_obj_set);
#line 532 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	_tmp17_ = _tmp16_;
#line 532 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	_tmp18_ = obj_set;
#line 532 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	_tmp19_ = gee_abstract_collection_get_size ((GeeCollection*) _tmp18_);
#line 532 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	_tmp20_ = _tmp19_;
#line 532 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	_vala_assert (_tmp17_ == _tmp20_, "new_obj_set.size == obj_set.size");
#line 484 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	_g_object_unref0 (obj_set);
#line 484 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	block11_data_unref (_data11_);
#line 484 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	_data11_ = NULL;
#line 3338 "object-cache.c"
}


static void object_cache_tests_class_init (ObjectCacheTestsClass * klass) {
#line 58 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	object_cache_tests_parent_class = g_type_class_peek_parent (klass);
#line 58 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	g_type_class_add_private (klass, sizeof (ObjectCacheTestsPrivate));
#line 58 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	((FolksTestCaseClass *) klass)->set_up = object_cache_tests_real_set_up;
#line 58 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	((FolksTestCaseClass *) klass)->tear_down = object_cache_tests_real_tear_down;
#line 58 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	G_OBJECT_CLASS (klass)->finalize = object_cache_tests_finalize;
#line 3353 "object-cache.c"
}


static void object_cache_tests_instance_init (ObjectCacheTests * self) {
#line 58 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	self->priv = OBJECT_CACHE_TESTS_GET_PRIVATE (self);
#line 3360 "object-cache.c"
}


static void object_cache_tests_finalize (GObject* obj) {
	ObjectCacheTests * self;
#line 58 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, TYPE_OBJECT_CACHE_TESTS, ObjectCacheTests);
#line 60 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	_g_object_unref0 (self->priv->_cache_dir);
#line 58 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	G_OBJECT_CLASS (object_cache_tests_parent_class)->finalize (obj);
#line 3372 "object-cache.c"
}


GType object_cache_tests_get_type (void) {
	static volatile gsize object_cache_tests_type_id__volatile = 0;
	if (g_once_init_enter (&object_cache_tests_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (ObjectCacheTestsClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) object_cache_tests_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ObjectCacheTests), 0, (GInstanceInitFunc) object_cache_tests_instance_init, NULL };
		GType object_cache_tests_type_id;
		object_cache_tests_type_id = g_type_register_static (FOLKS_TYPE_TEST_CASE, "ObjectCacheTests", &g_define_type_info, 0);
		g_once_init_leave (&object_cache_tests_type_id__volatile, object_cache_tests_type_id);
	}
	return object_cache_tests_type_id__volatile;
}


gint _vala_main (gchar** args, int args_length1) {
	gint result = 0;
	ObjectCacheTests* tests = NULL;
	ObjectCacheTests* _tmp0_ = NULL;
#line 538 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	g_test_init (&args_length1, &args, NULL);
#line 540 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	_tmp0_ = object_cache_tests_new ();
#line 540 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	tests = _tmp0_;
#line 541 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	folks_test_case_register ((FolksTestCase*) tests);
#line 542 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	g_test_run ();
#line 543 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	folks_test_case_final_tear_down ((FolksTestCase*) tests);
#line 545 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	result = 0;
#line 545 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	_g_object_unref0 (tests);
#line 545 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	return result;
#line 3410 "object-cache.c"
}


int main (int argc, char ** argv) {
#if !GLIB_CHECK_VERSION (2,35,0)
	g_type_init ();
#endif
#line 536 "/opt/gnome3/source/folks/tests/folks/object-cache.vala"
	return _vala_main (argv, argc);
#line 3420 "object-cache.c"
}


static void _vala_array_destroy (gpointer array, gint array_length, GDestroyNotify destroy_func) {
	if ((array != NULL) && (destroy_func != NULL)) {
		int i;
		for (i = 0; i < array_length; i = i + 1) {
			if (((gpointer*) array)[i] != NULL) {
				destroy_func (((gpointer*) array)[i]);
			}
		}
	}
}


static void _vala_array_free (gpointer array, gint array_length, GDestroyNotify destroy_func) {
	_vala_array_destroy (array, array_length, destroy_func);
	g_free (array);
}



